@@ -1,13 +1,14 @@
 import $ from 'jquery';
-import { n__, s__ } from '~/locale';
+import { __, n__, s__ } from '~/locale';
 import { createAlert } from '~/alert';
 import createDefaultClient from '~/lib/graphql';
 import { sanitize } from '~/lib/dompurify';
 import { loadingIconForLegacyJS } from '~/loading_icon_for_legacy_js';
 import commitDetailsQuery from '~/projects/commits/graphql/queries/commit_details.query.graphql';
+import { getParameterByName, removeParams } from '~/lib/utils/url_utility';
+import { InfiniteScroller } from '~/infinite_scroller';
 import axios from './lib/utils/axios_utils';
 import { localTimeAgo } from './lib/utils/datetime_utility';
-import Pager from './pager';
 
 const NEWLINE_CHAR = '&#x000A;';
 
@@ -35,15 +36,13 @@ const fetchCommitDetails = async (commitId) => {
 
 export default class CommitsList {
   constructor(limit = 0) {
+    this.limit = limit;
     this.timer = null;
 
     this.$contentList = $('.content_list');
-
-    Pager.init({ limit: parseInt(limit, 10), prepareData: this.processCommits.bind(this) });
-
-    this.content = $('#commits-list');
     this.searchField = $('#commits-search');
     this.lastSearch = this.searchField.val();
+    this.startInfiniteScroller();
     this.initSearch();
     this.initCommitDetails();
   }
@@ -57,13 +56,15 @@ export default class CommitsList {
   }
 
   initCommitDetails() {
-    this.content.on('click', '.js-toggle-button', ({ currentTarget }) =>
+    this.$contentList.on('click', '.js-toggle-button', ({ currentTarget }) =>
       this.handleToggleCommitDetails(currentTarget.dataset),
     );
   }
 
   async handleToggleCommitDetails({ commitId }) {
-    const contentElement = this.content.find(`.js-toggle-content[data-commit-id="${commitId}"]`);
+    const contentElement = this.$contentList.find(
+      `.js-toggle-content[data-commit-id="${commitId}"]`,
+    );
     if (!contentElement || contentElement.data('content-loaded')) return;
     contentElement.html(loadingIconForLegacyJS({ inline: true, size: 'sm' }));
 
@@ -85,44 +86,75 @@ export default class CommitsList {
     const form = $('.commits-search-form');
     const search = this.searchField.val();
     if (search === this.lastSearch) return Promise.resolve();
-    const commitsUrl = `${form.attr('action')}?${form.serialize()}`;
-    this.content.addClass('gl-opacity-5');
-    const params = form.serializeArray().reduce(
-      (acc, obj) =>
-        Object.assign(acc, {
-          [obj.name]: obj.value,
-        }),
-      {},
-    );
+    const baseUrl = form.attr('action');
+    const requestUrl = new URL(baseUrl, window.location.origin);
+    const params = new URLSearchParams(form.serialize());
+    for (const [key, value] of params) {
+      if (value) requestUrl.searchParams.append(key, value);
+    }
+    const serializedRequestUrl = requestUrl.toString();
+
+    this.$contentList.addClass('gl-opacity-5');
 
     return axios
-      .get(form.attr('action'), {
-        params,
-      })
+      .get(serializedRequestUrl)
       .then(({ data }) => {
         this.lastSearch = search;
-        this.content.html(data.html);
-        this.content.removeClass('gl-opacity-5');
-
-        // Change url so if user reload a page - search results are saved
+        this.$contentList.html(data.html);
+        this.$contentList.removeClass('gl-opacity-5');
+        this.startInfiniteScroller();
         window.history.replaceState(
           {
-            page: commitsUrl,
+            page: serializedRequestUrl,
           },
           document.title,
-          commitsUrl,
+          serializedRequestUrl,
         );
       })
-      .catch(() => {
-        this.content.removeClass('gl-opacity-5');
+      .catch((error) => {
+        createAlert({
+          message: __('Failed to load more commits. Please try to reload the page'),
+          error,
+        });
+        this.$contentList.removeClass('gl-opacity-5');
         this.lastSearch = null;
       });
   }
 
+  startInfiniteScroller() {
+    if (this.scroller) this.scroller.destroy();
+    const root = document.querySelector('.js-infinite-scrolling-root');
+    this.scroller = new InfiniteScroller({
+      root,
+      fetchNextPage: async (offset, signal) => {
+        return axios
+          .get(removeParams(['limit', 'offset']), {
+            params: { limit: this.limit, offset },
+            signal,
+          })
+          .then(({ data }) => {
+            const html = this.processCommits(data);
+            return { count: data.count, html };
+          })
+          .catch((error) => {
+            if (axios.isCancel(error)) return null;
+            throw error;
+          });
+      },
+      limit: this.limit,
+      startingOffset: parseInt(getParameterByName('offset'), 10) || this.limit,
+    });
+    if (this.$contentList.find('[data-empty-list]').length) {
+      this.scroller.setLoadingVisibility(false);
+    } else {
+      this.scroller.initialize();
+    }
+  }
+
   // Prepare loaded data.
   processCommits(data) {
-    let processedData = data;
-    const $processedData = $(processedData);
+    let { html } = data;
+    const $processedData = $(data);
     const $commitsHeadersLast = this.$contentList.find('li.js-commit-header').last();
     const lastShownDay = $commitsHeadersLast.data('day');
     const $loadedCommitsHeadersFirst = $processedData.filter('li.js-commit-header').first();
@@ -135,8 +167,11 @@ export default class CommitsList {
       // Last shown commits count under the last commits header.
       commitsCount = $commitsHeadersLast.nextUntil('li.js-commit-header').find('li.commit').length;
 
+      const processedData = $processedData.not(
+        `li.js-commit-header[data-day='${loadedShownDayFirst}']`,
+      );
       // Remove duplicate of commits header.
-      processedData = $processedData.not(`li.js-commit-header[data-day='${loadedShownDayFirst}']`);
+      html = processedData.html();
 
       // Update commits count in the previous commits header.
       commitsCount += Number(
@@ -150,6 +185,6 @@ export default class CommitsList {
 
     localTimeAgo($processedData.find('.js-timeago').get());
 
-    return processedData;
+    return html;
   }
 }
