@@ -1,8 +1,11 @@
 import { contentTop } from './common_utils';
+import { getScrollingElement } from './scroll_utils';
 
 /**
- * Watches for change in size of a container element (e.g. for lazy-loaded images)
+ * Watches for change in size of a container element
+ * (e.g. lazy-loaded images or paginated notes)
  * and scrolls the target note to the top of the content area.
+ *
  * Stops watching if the target element is scrolled out of viewport
  *
  * @param {Object} options
@@ -17,6 +20,9 @@ export function scrollToTargetOnResize({
 } = {}) {
   if (!targetId) return null;
 
+  const containerEl = document.querySelector(container);
+  const scrollingElement = getScrollingElement(containerEl);
+
   let targetElement = null;
   let targetTop = 0;
   let currentScrollPosition = 0;
@@ -26,20 +32,18 @@ export function scrollToTargetOnResize({
   let scrollListenerEnabled = false;
   let intersectionObserver = null;
 
-  const containerEl = document.querySelector(container);
-
-  let { scrollHeight } = document.scrollingElement;
+  let { scrollHeight } = scrollingElement;
 
   const ro = new ResizeObserver((entries) => {
     entries.forEach(() => {
-      scrollHeight = document.scrollingElement.scrollHeight;
+      scrollHeight = scrollingElement.scrollHeight;
       // eslint-disable-next-line no-use-before-define
       keepTargetAtTop();
     });
   });
 
   function handleScroll() {
-    const diff = document.scrollingElement.scrollHeight - scrollHeight;
+    const diff = scrollingElement.scrollHeight - scrollHeight;
     if (Math.abs(diff) > 100) {
       return;
     }
@@ -49,11 +53,11 @@ export function scrollToTargetOnResize({
   }
 
   function addScrollListener() {
-    window.addEventListener('scroll', handleScroll, { passive: true });
+    scrollingElement.addEventListener('scroll', handleScroll, { passive: true });
   }
 
   function removeScrollListener() {
-    window.removeEventListener('scroll', handleScroll);
+    scrollingElement.removeEventListener('scroll', handleScroll);
   }
 
   function setupIntersectionObserver() {
@@ -71,21 +75,26 @@ export function scrollToTargetOnResize({
   }
 
   function keepTargetAtTop() {
-    if (document.activeElement !== document.body) return;
+    const superTopbar = document.querySelector('.js-super-topbar');
+
+    // once the user has selected or focused on an element, skip auto-scrolling for them
+    if (![document.body, superTopbar].includes(document.activeElement)) return;
 
     targetElement = document.getElementById(targetId);
 
+    // skip if the element hasn't loaded yet
     if (!targetElement) return;
 
     const anchorTop = targetElement.getBoundingClientRect().top;
-    currentScrollPosition = document.scrollingElement.scrollTop;
+
+    currentScrollPosition = scrollingElement.scrollTop;
 
     // Add scrollPosition as getBoundingClientRect is relative to viewport
     // Add the accumulated scroll offset to maintain relative position
     // subtract contentTop so it goes below sticky headers, rather than top of viewport
     targetTop = anchorTop + currentScrollPosition - userScrollOffset - contentTop();
 
-    document.scrollingElement.scrollTo({ top: targetTop, behavior: 'instant' });
+    scrollingElement.scrollTo({ top: targetTop, behavior: 'instant' });
 
     if (!scrollListenerEnabled) {
       addScrollListener();
