@@ -9,8 +9,8 @@ import {
   isMetaClick,
   NO_SCROLL_TO_HASH_CLASS,
   parseBoolean,
-  scrollToElement,
 } from '~/lib/utils/common_utils';
+import { getScrollingElement, scrollTo, scrollToElement } from '~/lib/utils/scroll_utils';
 import { parseUrlPathname, visitUrl } from '~/lib/utils/url_utility';
 import createEventHub from '~/helpers/event_hub_factory';
 import { renderGFM } from '~/behaviors/markdown/render_gfm';
@@ -81,10 +81,10 @@ let { location } = window;
 
 function scrollToContainer(container) {
   if (location.hash) {
-    const $el = $(`${container} ${location.hash}:not(.match)`);
+    const el = document.querySelector(`${container} ${location.hash}:not(.match)`);
 
-    if ($el.length) {
-      scrollToElement($el[0]);
+    if (el) {
+      scrollToElement(el);
     }
   }
 }
@@ -111,6 +111,9 @@ function mountPipelines() {
       mergeRequestId: mrWidgetData ? mrWidgetData.iid : null,
       sourceProjectFullPath: mrWidgetData?.source_project_full_path || '',
       useFailedJobsWidget: true,
+      mergeRequestPath: mrWidgetData?.merge_request_path
+        ? `${gon.gitlab_url}${mrWidgetData.merge_request_path}`
+        : null,
     },
     render(createElement) {
       return createElement('merge-request-pipelines-table', {
@@ -210,7 +213,6 @@ export default class MergeRequestTabs {
       this.mergeRequestTabPanes && this.mergeRequestTabPanes.querySelectorAll
         ? this.mergeRequestTabPanes.querySelectorAll('.tab-pane')
         : null;
-    this.navbar = document.querySelector('.navbar-gitlab');
     this.peek = document.getElementById('js-peek');
     this.sidebar = document.querySelector('.js-right-sidebar');
     this.pageLayout = document.querySelector('.layout-page');
@@ -277,7 +279,7 @@ export default class MergeRequestTabs {
 
   storeScroll() {
     if (this.currentTab) {
-      this.scrollPositions[this.currentTab] = document.documentElement.scrollTop;
+      this.scrollPositions[this.currentTab] = getScrollingElement().scrollTop;
     }
   }
   recallScroll(action) {
@@ -285,7 +287,7 @@ export default class MergeRequestTabs {
     if (storedPosition == null) return;
 
     setTimeout(() => {
-      window.scrollTo({
+      scrollTo({
         top: storedPosition > 0 ? storedPosition : 0,
         left: 0,
         behavior: 'auto',
@@ -426,14 +428,15 @@ export default class MergeRequestTabs {
         // 51px is the height of the navbar buttons, e.g. `Discussion | Commits | Changes`
         const scrollDestination = tabContentTop - mainContentTop - 51;
 
-        // scrollBehavior is only available in browsers that support scrollToOptions
-        if ('scrollBehavior' in document.documentElement.style && shouldScroll) {
-          window.scrollTo({
+        if (shouldScroll) {
+          scrollTo({
             top: scrollDestination,
             behavior: 'smooth',
           });
         } else {
-          window.scrollTo(0, scrollDestination);
+          scrollTo({
+            top: scrollDestination,
+          });
         }
       }
     }
@@ -562,7 +565,7 @@ export default class MergeRequestTabs {
   // load the legacy diff tab content from the backend
   loadDiff({ endpoint, strip = true }) {
     if (this.diffsLoaded) {
-      document.dispatchEvent(new CustomEvent('scroll'));
+      getScrollingElement().dispatchEvent(new CustomEvent('scroll'));
       return;
     }
 
@@ -612,9 +615,11 @@ export default class MergeRequestTabs {
   }
 
   expandViewContainer() {
-    this.contentWrapper.classList.remove('container-limited');
-    this.contentWrapper.classList.remove('rd-page-container');
-    this.contentWrapper.classList.add('diffs-container-limited');
+    if (this.contentWrapper.classList.contains('container-limited')) {
+      this.contentWrapper.classList.remove('container-limited');
+      this.contentWrapper.classList.remove('rd-page-container');
+      this.contentWrapper.classList.add('diffs-container-limited');
+    }
   }
 
   resetViewContainer() {
