@@ -1,4 +1,5 @@
 import Vue from 'vue';
+import { parseBoolean } from '~/lib/utils/common_utils';
 import DiscussionCounter from '~/notes/components/discussion_counter.vue';
 import { pinia } from '~/pinia/instance';
 
@@ -6,7 +7,7 @@ export function initDiscussionCounter() {
   const el = document.getElementById('js-vue-discussion-counter');
 
   if (el) {
-    const { blocksMerge } = el.dataset;
+    const { blocksMerge, canResolveDiscussion } = el.dataset;
 
     // eslint-disable-next-line no-new
     new Vue({
@@ -19,7 +20,8 @@ export function initDiscussionCounter() {
       render(createElement) {
         return createElement('discussion-counter', {
           props: {
-            blocksMerge: blocksMerge === 'true',
+            blocksMerge: parseBoolean(blocksMerge),
+            canResolveDiscussion: parseBoolean(canResolveDiscussion),
           },
         });
       },
