@@ -1,4 +1,4 @@
-import { showAlertFromLocalStorage } from '~/ci/runner/local_storage_alert/show_alert_from_local_storage';
+import { showAlertFromLocalStorage } from '~/lib/utils/local_storage_alert';
 import { initProjectRunnerShow } from '~/ci/runner/project_runner_show';
 
 showAlertFromLocalStorage();
