@@ -1,9 +1,9 @@
 import Wikis from '~/wikis/wikis';
 import { mountApplications } from '~/wikis/edit';
 import { mountMoreActions } from '~/wikis/more_actions';
-import { mountWikiSidebarEntries } from '~/wikis/show';
+import { mountWikiSidebar } from '~/wikis/show';
 
-mountWikiSidebarEntries();
+mountWikiSidebar();
 mountApplications();
 mountMoreActions();
 
