@@ -38,7 +38,7 @@ class Projects::IssuesController < Projects::ApplicationController
   before_action :authorize_create_issue!, only: [:new, :create]
 
   # Allow modify issue
-  before_action :authorize_update_issuable!, only: [:edit, :update, :move, :reorder]
+  before_action :authorize_update_issuable!, only: [:update, :move, :reorder]
 
   # Allow create a new branch and empty WIP merge request from current issue
   before_action :authorize_create_merge_request_from!, only: [:create_merge_request]
@@ -49,22 +49,12 @@ class Projects::IssuesController < Projects::ApplicationController
   before_action do
     push_frontend_feature_flag(:preserve_markdown, project)
     push_frontend_feature_flag(:service_desk_ticket)
-    push_frontend_feature_flag(:issues_list_create_modal, project)
-    push_frontend_feature_flag(:issues_list_drawer, project)
     push_frontend_feature_flag(:notifications_todos_buttons, current_user)
-    push_frontend_feature_flag(:work_item_planning_view, project&.group)
+    push_force_frontend_feature_flag(:work_item_planning_view, !!project&.work_items_consolidated_list_enabled?(current_user))
     push_force_frontend_feature_flag(:glql_load_on_click, !!project&.glql_load_on_click_feature_flag_enabled?)
-    push_force_frontend_feature_flag(:work_items_beta, !!project&.work_items_beta_feature_flag_enabled?)
-    push_force_frontend_feature_flag(:work_items_alpha, !!project&.work_items_alpha_feature_flag_enabled?)
-    push_frontend_feature_flag(:work_item_view_for_issues, project&.group)
-    push_frontend_feature_flag(:work_item_status_feature_flag, project&.root_ancestor)
     push_frontend_feature_flag(:hide_incident_management_features, project)
   end
 
-  before_action only: [:index, :show] do
-    push_force_frontend_feature_flag(:work_items, project&.work_items_feature_flag_enabled?)
-  end
-
   before_action only: :show do
     push_frontend_feature_flag(:epic_widget_edit_confirmation, project)
   end
@@ -97,6 +87,8 @@ class Projects::IssuesController < Projects::ApplicationController
   attr_accessor :vulnerability_id
 
   def index
+    return if redirect_if_epic_params
+
     if index_html_request?
       set_sort_order
     else
@@ -140,18 +132,35 @@ class Projects::IssuesController < Projects::ApplicationController
   end
 
   def show
-    return super unless show_work_item? && request.format.html?
+    return super unless issue.show_as_work_item? && request.format.html?
 
-    @right_sidebar = false
-    @work_item = issue.becomes(::WorkItem) # rubocop:disable Cop/AvoidBecomes -- We need the instance to be a work item
+    if project&.work_items_consolidated_list_enabled?(current_user)
+      if params[:vueroute].present? && request.path.include?('/designs/')
+        # Only redirect to designs path if both vueroute param exists and path contains /designs/
+        # Needed since designs are aliased to show in this controller
+        redirect_to designs_project_work_item_path(project, issue.iid, vueroute: params[:vueroute], params: request.query_parameters)
+      else
+        redirect_to project_work_item_path(project, issue.iid, params: request.query_parameters)
+      end
+    else
+      @right_sidebar = false
+      @work_item = issue.becomes(::WorkItem) # rubocop:disable Cop/AvoidBecomes -- We need the instance to be a work item
 
-    render 'projects/work_items/show'
+      render 'projects/work_items/show'
+    end
   end
 
   alias_method :designs, :show
 
   def edit
-    respond_with(@issue)
+    # Check if user can edit the issue
+    if can?(current_user, :update_issue, issue)
+      # Redirect to issues detail page with edit mode enabled
+      redirect_to project_issue_path(project, issue, edit: 'true')
+    else
+      # Redirect to issues detail page without edit mode
+      redirect_to project_issue_path(project, issue)
+    end
   end
 
   def create
@@ -247,6 +256,8 @@ class Projects::IssuesController < Projects::ApplicationController
   end
 
   def create_merge_request
+    Labkit::UserExperienceSli.start(:create_merge_request)
+
     create_params = params.slice(:branch_name, :ref).merge(issue_iid: issue.iid)
     create_params[:target_project_id] = params[:target_project_id]
     result = ::MergeRequests::CreateFromIssueService.new(project: project, current_user: current_user, mr_params: create_params).execute
@@ -407,7 +418,7 @@ class Projects::IssuesController < Projects::ApplicationController
   private
 
   def disable_show_query_limit!
-    Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/544875', new_threshold: 120)
+    Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/544875', new_threshold: 130)
   end
 
   def disable_create_query_limit!
@@ -416,13 +427,6 @@ class Projects::IssuesController < Projects::ApplicationController
     Gitlab::QueryLimiting.disable!('https://gitlab.com/gitlab-org/gitlab/-/issues/546668', new_threshold: 150)
   end
 
-  def show_work_item?
-    # Service Desk issues and incidents should not use the work item view
-    !issue.from_service_desk? &&
-      !issue.work_item_type&.incident? &&
-      Feature.enabled?(:work_item_view_for_issues, project&.group)
-  end
-
   def work_item_redirect_except_actions
     ISSUES_EXCEPT_ACTIONS
   end
@@ -444,7 +448,7 @@ class Projects::IssuesController < Projects::ApplicationController
 
   def clean_params(all_params)
     issue_type = all_params[:issue_type].to_s
-    all_params.delete(:issue_type) unless WorkItems::Type.allowed_types_for_issues.include?(issue_type)
+    all_params.delete(:issue_type) unless ::WorkItems::TypesFilter.allowed_types_for_issues.include?(issue_type)
 
     all_params
   end
@@ -457,7 +461,7 @@ class Projects::IssuesController < Projects::ApplicationController
 
     if service_desk?
       options.reject! { |key| key == 'author_username' || key == 'author_id' }
-      options[:author_id] = Users::Internal.support_bot
+      options[:author_id] = Users::Internal.for_organization(project.organization_id).support_bot
     end
 
     options
@@ -478,14 +482,21 @@ class Projects::IssuesController < Projects::ApplicationController
   def redirect_if_work_item
     return unless use_work_items_path?(issue)
 
-    redirect_to project_work_item_path(project, issue.iid, params: request.query_parameters)
+    query_params = request.query_parameters
+    query_params = query_params.merge(edit: 'true') if action_name == 'edit' && can?(current_user, :update_issue, issue)
+
+    redirect_to project_work_item_path(project, issue.iid, query_params)
   end
 
   def redirect_index_to_work_items
-    return unless index_html_request? && ::Feature.enabled?(:work_item_planning_view, project.group)
+    return unless index_html_request? && project&.work_items_consolidated_list_enabled?(current_user)
 
-    params = request.query_parameters.except("type").merge('type[]' => 'issue')
-    redirect_to project_work_items_path(project, params: params)
+    redirect_to project_work_items_path(project, params: work_items_redirect_params(request.query_parameters))
+  end
+
+  # Overridden in EE
+  def work_items_redirect_params(params)
+    params.except("type", "type[]")
   end
 
   def require_incident_for_incident_routes
@@ -496,6 +507,9 @@ class Projects::IssuesController < Projects::ApplicationController
     # issue type changes
     redirect_to project_issue_path(project, issue)
   end
+
+  # Overridden in EE
+  def redirect_if_epic_params; end
 end
 
 Projects::IssuesController.prepend_mod_with('Projects::IssuesController')
