@@ -29,6 +29,10 @@ module Types
       description: 'Merge request dashboard list rendering type.',
       null: true
 
+    field :merge_request_dashboard_show_drafts, GraphQL::Types::Boolean,
+      description: 'Show draft merge requests on merge request dashboard.',
+      null: true
+
     field :projects_sort,
       Types::Projects::ProjectSortEnum,
       description: 'Sort order for projects.',
@@ -58,6 +62,11 @@ module Types
       null: false,
       description: 'Display settings for the work item lists.'
 
+    field :new_ui_enabled, GraphQL::Types::Boolean,
+      description: 'Whether the new UI is enabled for the user.',
+      experiment: { milestone: '18.6' },
+      null: true
+
     def issues_sort
       user_preference.issues_sort&.to_sym
     end
