@@ -128,24 +128,17 @@ module GroupsHelper
     }
   end
 
-  def group_overview_tabs_app_data(group)
+  def groups_show_app_data(group)
     {
-      group_id: group.id,
-      subgroups_and_projects_endpoint:
-        group_children_path(group, format: :json, archived: false, not_aimed_for_deletion: true),
-      shared_projects_endpoint: group_shared_projects_path(group, format: :json),
-      inactive_projects_endpoint: group_children_path(group, format: :json, active: false),
-      current_group_visibility: group.visibility,
+      subgroups_and_projects_endpoint: group_children_path(group, format: :json),
       initial_sort: project_list_sort_by,
-      show_schema_markup: 'true',
+      full_path: group.full_path,
       new_subgroup_path: new_group_path(parent_id: group.id, anchor: 'create-group-pane'),
       new_project_path: new_project_path(namespace_id: group.id),
-      empty_projects_illustration: image_path('illustrations/empty-state/empty-projects-md.svg'),
-      empty_subgroup_illustration: image_path('illustrations/empty-state/empty-projects-md.svg'),
-      render_empty_state: 'true',
-      can_create_subgroups: can?(current_user, :create_subgroup, group).to_s,
-      can_create_projects: can?(current_user, :create_projects, group).to_s
-    }
+      can_create_subgroups: can?(current_user, :create_subgroup, group),
+      can_create_projects: can?(current_user, :create_projects, group),
+      empty_projects_illustration: image_path('illustrations/empty-state/empty-projects-md.svg')
+    }.to_json
   end
 
   def group_readme_app_data(group_readme)
@@ -205,11 +198,6 @@ module GroupsHelper
     new_group_custom_emoji_path(group)
   end
 
-  def access_level_roles_user_can_assign(group, roles)
-    max_access_level = group.max_member_access_for_user(current_user)
-    Authz::Role.roles_user_can_assign(max_access_level, roles)
-  end
-
   def groups_projects_more_actions_dropdown_data(source)
     model_name = source.model_name.to_s.downcase
     dropdown_data = {
@@ -246,7 +234,8 @@ module GroupsHelper
   def groups_list_with_filtered_search_app_data(endpoint)
     {
       endpoint: endpoint,
-      initial_sort: project_list_sort_by
+      initial_sort: project_list_sort_by,
+      base_path: dashboard_groups_path
     }.to_json
   end
 
@@ -254,6 +243,14 @@ module GroupsHelper
     MergeRequestsFinder.new(current_user, group_id: group.id, include_subgroups: true, non_archived: true).execute
   end
 
+  def step_up_auth_provider_options_for_select
+    available_step_up_auth_providers_for_namespace.map do |provider|
+      provider_config = Gitlab::Auth::OAuth::Provider.config_for(provider.to_s)
+      provider_label = provider_config[:label].presence || provider.to_s.humanize
+      [provider_label, provider.to_s]
+    end
+  end
+
   private
 
   def group_title_link(group, hidable: false, show_avatar: false)
@@ -331,6 +328,12 @@ module GroupsHelper
       other: _('A different reason')
     }.with_indifferent_access.freeze
   end
+
+  def available_step_up_auth_providers_for_namespace
+    Gitlab::Auth::Oidc::StepUpAuthentication.enabled_providers(
+      scope: Gitlab::Auth::Oidc::StepUpAuthentication::SCOPE_NAMESPACE
+    )
+  end
 end
 
 GroupsHelper.prepend_mod_with('GroupsHelper')
