@@ -174,6 +174,9 @@ module MergeRequestsHelper
     false
   end
 
+  # Overriden in EE
+  def summarize_new_merge_request_disabled_reason(_merge_request); end
+
   def diffs_tab_pane_data(project, merge_request, params)
     {
       "is-locked": merge_request.discussion_locked?,
@@ -272,7 +275,6 @@ module MergeRequestsHelper
       releases_endpoint: project_releases_path(project, format: :json),
       can_bulk_update: can?(current_user, :admin_merge_request, project).to_s,
       environment_names_path: unfoldered_environment_names_project_path(project, :json),
-      default_branch: project.default_branch,
       initial_email: can?(current_user, :create_merge_request_in, project) &&
         project.new_issuable_address(current_user, 'merge_request')
     })
@@ -295,14 +297,10 @@ module MergeRequestsHelper
     { identity_verification_required: 'false' }
   end
 
-  def merge_request_dashboard_enabled?(current_user)
-    current_user.merge_request_dashboard_enabled?
-  end
-
   def sticky_header_data(project, merge_request)
     data = {
       iid: merge_request.iid,
-      canResolveDiscussion: merge_request.resolvable_discussions.first&.can_resolve_discussion?(current_user).to_s,
+      canResolveDiscussion: merge_request.resolvable_discussions.first&.can_resolve?(current_user).to_s,
       defaultBranchName: project.default_branch,
       projectPath: project.full_path,
       sourceProjectPath: merge_request.source_project_path,
@@ -340,7 +338,6 @@ module MergeRequestsHelper
 
   def show_mr_dashboard_banner?
     request.query_string.present? &&
-      merge_request_dashboard_enabled?(current_user) &&
       current_page?(merge_requests_search_dashboard_path) &&
       show_new_mr_dashboard_banner?
   end
@@ -350,8 +347,6 @@ module MergeRequestsHelper
   end
 
   def merge_request_dashboard_show_drafts?
-    return true if Feature.disabled?(:mr_dashboard_drafts_toggle, current_user)
-
     current_user.merge_request_dashboard_show_drafts
   end
 
@@ -407,7 +402,7 @@ module MergeRequestsHelper
     target_branch_class = "ref-container gl-inline-block gl-truncate gl-max-w-26 gl-shrink-0"
     copy_action_description = _('Copy branch name')
     copy_action_shortcut = 'b'
-    copy_button_title = "#{copy_action_description} <kbd class='flat ml-1' " \
+    copy_button_title = "#{copy_action_description} <kbd class='flat gl-ml-2' " \
       "aria-hidden=true>#{copy_action_shortcut}</kbd>"
 
     target_branch_class = if @project.default_branch != merge_request.target_branch
@@ -421,14 +416,14 @@ module MergeRequestsHelper
       title: copy_button_title,
       aria_keyshortcuts: copy_action_shortcut,
       aria_label: copy_action_description,
-      class: '!gl-hidden md:!gl-inline-block gl-mx-1 js-source-branch-copy'
+      class: '!gl-hidden @md/panel:!gl-inline-block gl-mx-1 js-source-branch-copy'
     )
 
     target_copy_button = clipboard_button(
       text: merge_request.target_branch,
       title: copy_action_description,
       aria_label: copy_action_description,
-      class: '!gl-hidden md:!gl-inline-block gl-mx-1'
+      class: '!gl-hidden @md/panel:!gl-inline-block gl-mx-1'
     )
 
     target_branch = link_to merge_request.target_branch,
@@ -468,7 +463,10 @@ module MergeRequestsHelper
   end
 
   def review_bar_data(_merge_request, _user)
-    { new_comment_template_paths: new_comment_template_paths(@project.group, @project).to_json }
+    {
+      diffs_path: diffs_project_merge_request_url(@project, @merge_request),
+      new_comment_template_paths: new_comment_template_paths(@project.group, @project).to_json
+    }
   end
 
   def merge_request_dashboard_role_based_data
