@@ -17,6 +17,27 @@ class NotifyPreview < ActionMailer::Preview
     end
   end
 
+  def note_wiki_page_email_for_individual_note
+    note_email(:note_wiki_page_email) do
+      note = <<-MD.strip_heredoc
+        This is an individual note on a merge request :smiley:
+
+        In this notification email, we expect to see:
+
+        - The note contents (that's what you're looking at)
+        - A link to view this note on GitLab
+        - An explanation for why the user is receiving this notification
+      MD
+
+      create_note(
+        noteable_type: 'WikiPage::Meta',
+        noteable_id: wiki_page_meta.id,
+        note: note,
+        project: wiki_page_meta.project
+      )
+    end
+  end
+
   def new_user_email
     Notify.new_user_email(user.id).message
   end
@@ -91,6 +112,10 @@ class NotifyPreview < ActionMailer::Preview
     Notify.access_token_about_to_expire_email(user, ['%w', '%w']).message
   end
 
+  def deploy_token_about_to_expire_email
+    Notify.deploy_token_about_to_expire_email(user, 'token_name', project).message
+  end
+
   def ssh_key_expired_email
     fingerprints = []
     Notify.ssh_key_expired_email(user, fingerprints).message
@@ -147,6 +172,10 @@ class NotifyPreview < ActionMailer::Preview
     end
   end
 
+  def new_gpg_key_email
+    Notify.new_gpg_key_email(gpg_key.id).message
+  end
+
   def closed_merge_request_email
     Notify.closed_merge_request_email(user.id, merge_request.id, user.id).message
   end
@@ -171,17 +200,6 @@ class NotifyPreview < ActionMailer::Preview
     Notify.changed_milestone_merge_request_email(user.id, merge_request.id, milestone, user.id)
   end
 
-  def member_access_granted_email
-    Notify.member_access_granted_email(member.source_type, member.id).message
-  end
-
-  def member_about_to_expire_email
-    cleanup do
-      member = project.add_member(user, Gitlab::Access::GUEST, expires_at: 7.days.from_now.to_date)
-      Notify.member_about_to_expire_email('project', member.id).message
-    end
-  end
-
   def pages_domain_enabled_email
     cleanup do
       Notify.pages_domain_enabled_email(pages_domain, user).message
@@ -224,6 +242,26 @@ class NotifyPreview < ActionMailer::Preview
     Notify.pipeline_fixed_email(pipeline, pipeline.user.try(:email))
   end
 
+  def pipeline_variables_migration_complete_email
+    Notify.pipeline_variables_migration_complete_email(user, group, { updated_count: 5, skipped_count: 3 }).message
+  end
+
+  def pipeline_variables_migration_complete_email_all_updated
+    Notify.pipeline_variables_migration_complete_email(user, group, { updated_count: 10, skipped_count: 0 }).message
+  end
+
+  def pipeline_variables_migration_complete_email_single_project
+    Notify.pipeline_variables_migration_complete_email(user, group, { updated_count: 1, skipped_count: 0 }).message
+  end
+
+  def pipeline_variables_migration_complete_email_single_skipped
+    Notify.pipeline_variables_migration_complete_email(user, group, { updated_count: 2, skipped_count: 1 }).message
+  end
+
+  def pipeline_schedule_owner_unavailable
+    Notify.pipeline_schedule_owner_unavailable_email(pipeline_schedule, user)
+  end
+
   def autodevops_disabled_email
     Notify.autodevops_disabled_email(pipeline, user.email).message
   end
@@ -240,10 +278,34 @@ class NotifyPreview < ActionMailer::Preview
     Notify.two_factor_otp_attempt_failed_email(user, '127.0.0.1').message
   end
 
+  def enabled_two_factor_passkey_email
+    Notify.enabled_two_factor_webauthn_email(user, 'MacBook Touch ID', :passkey).message
+  end
+
+  def enabled_two_factor_otp_email
+    Notify.enabled_two_factor_otp_email(user).message
+  end
+
+  def enabled_two_factor_webauthn_email
+    Notify.enabled_two_factor_webauthn_email(user, 'MacBook Touch ID').message
+  end
+
   def disabled_two_factor_email
     Notify.disabled_two_factor_email(user).message
   end
 
+  def disabled_two_factor_passkey_email
+    Notify.disabled_two_factor_webauthn_email(user, 'MacBook Touch ID', :passkey).message
+  end
+
+  def disabled_two_factor_otp_email
+    Notify.disabled_two_factor_otp_email(user).message
+  end
+
+  def disabled_two_factor_webauthn_email
+    Notify.disabled_two_factor_webauthn_email(user, 'MacBook Touch ID').message
+  end
+
   def new_email_address_added_email
     Notify.new_email_address_added_email(user, 'someone@gitlab.com').message
   end
@@ -427,6 +489,12 @@ class NotifyPreview < ActionMailer::Preview
     Notify.import_source_user_rejected(source_user.id)
   end
 
+  def import_source_user_complete
+    source_user = Import::SourceUser.last
+
+    Notify.import_source_user_complete(source_user.id)
+  end
+
   def repository_rewrite_history_success_email
     Notify.repository_rewrite_history_success_email(project, user)
   end
@@ -435,6 +503,25 @@ class NotifyPreview < ActionMailer::Preview
     Notify.repository_rewrite_history_failure_email(project, user, 'Error message')
   end
 
+  def project_scheduled_for_deletion
+    cleanup do
+      project.update!(marked_for_deletion_at: Time.current)
+
+      ::Notify.project_scheduled_for_deletion(user.id, project.id).message
+    end
+  end
+
+  def group_scheduled_for_deletion
+    cleanup do
+      group.create_deletion_schedule!(
+        marked_for_deletion_on: Time.current,
+        deleting_user: user
+      )
+
+      ::Notify.group_scheduled_for_deletion(user.id, group.id).message
+    end
+  end
+
   private
 
   def project
@@ -498,6 +585,10 @@ class NotifyPreview < ActionMailer::Preview
     @merge_request ||= project.merge_requests.first
   end
 
+  def wiki_page_meta
+    @wiki_page_meta ||= WikiPage::Meta.last
+  end
+
   def milestone
     @milestone ||= issue.milestone
   end
@@ -506,6 +597,10 @@ class NotifyPreview < ActionMailer::Preview
     @pipeline = Ci::Pipeline.last
   end
 
+  def pipeline_schedule
+    @pipeline_schedule ||= Ci::PipelineSchedule.last
+  end
+
   def remote_mirror
     @remote_mirror ||= RemoteMirror.last
   end
@@ -530,6 +625,14 @@ class NotifyPreview < ActionMailer::Preview
     Key.last || Keys::CreateService.new(user).execute
   end
 
+  def gpg_key
+    @gpg_key ||= find_or_create_gpg_key
+  end
+
+  def find_or_create_gpg_key
+    GpgKey.last || GpgKeys::CreateService.new(user, key: GpgHelpers::User1.public_key).execute
+  end
+
   def create_note(params)
     Notes::CreateService.new(project, user, params).execute
   end
@@ -553,7 +656,7 @@ class NotifyPreview < ActionMailer::Preview
     # will obtain an exclusive lease.
     # The `cleanup` method wraps the email-generating-block in a transaction.
     # See issue: https://gitlab.com/gitlab-org/gitlab/-/issues/441523
-    Users::Internal.support_bot
+    Users::Internal.for_organization(project.organization_id).support_bot
   end
 
   def ensure_visual_review_bot_exists
