@@ -6,6 +6,7 @@ class Group < Namespace
   include Gitlab::ConfigHelper
   include AfterCommitQueue
   include AccessRequestable
+  include Authz::HasRoles
   include Avatarable
   include SelectForProjectAuthorization
   include LoadedInGroupList
@@ -186,6 +187,7 @@ class Group < Namespace
     :setup_for_company,
     :step_up_auth_required_oauth_provider,
     :step_up_auth_required_oauth_provider=,
+    :step_up_auth_required_oauth_provider_from_self_or_inherited,
     to: :namespace_settings
   )
 
@@ -246,17 +248,10 @@ class Group < Namespace
 
   scope :with_users, -> { includes(:users) }
 
-  scope :active, -> { non_archived.not_aimed_for_deletion }
+  scope :active, -> { self_and_ancestors_active }
   scope :self_and_ancestors_active, -> { self_and_ancestors_non_archived.self_and_ancestors_not_aimed_for_deletion }
 
-  scope :inactive, -> do
-    joins(:namespace_settings)
-      .left_joins(:deletion_schedule)
-      .where(<<~SQL)
-        #{reflections['namespace_settings'].table_name}.archived = TRUE
-        OR #{reflections['deletion_schedule'].table_name}.#{reflections['deletion_schedule'].foreign_key} IS NOT NULL
-      SQL
-  end
+  scope :inactive, -> { self_or_ancestors_inactive }
   scope :self_or_ancestors_inactive, -> { self_or_ancestors_archived.or(self_or_ancestors_aimed_for_deletion) }
 
   scope :with_non_archived_projects, -> { includes(:non_archived_projects) }
@@ -268,7 +263,7 @@ class Group < Namespace
     where('id IN (SELECT id FROM accessible_sub_namespace_ids)')
   end
 
-  scope :by_id, ->(groups) { where(id: groups) }
+  scope :by_id, ->(groups) { id_in(groups) }
 
   scope :by_ids_or_paths, ->(ids, paths) do
     return by_id(ids) unless paths.present?
@@ -672,11 +667,11 @@ class Group < Namespace
   end
 
   def visibility_level_allowed_by_projects?(level = self.visibility_level)
-    !projects.not_aimed_for_deletion.where('visibility_level > ?', level).exists?
+    !projects.not_aimed_for_deletion.with_visibility_level_greater_than(level).exists?
   end
 
   def visibility_level_allowed_by_sub_groups?(level = self.visibility_level)
-    !children.where('visibility_level > ?', level).exists?
+    !children.with_visibility_level_greater_than(level).exists?
   end
 
   def visibility_level_allowed?(level = self.visibility_level)
@@ -1145,28 +1140,8 @@ class Group < Namespace
     ].compact.min
   end
 
-  def work_items_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:work_items)
-  end
-
-  def work_items_beta_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:work_items_beta, type: :beta)
-  end
-
-  def work_items_alpha_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:work_items_alpha)
-  end
-
-  def work_items_project_issues_list_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:work_items_project_issues_list, type: :beta)
-  end
-
-  def work_items_group_issues_list_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:work_items_group_issues_list, type: :beta)
-  end
-
-  def work_item_status_mvc2_feature_flag_enabled?
-    feature_flag_enabled_for_self_or_ancestor?(:work_item_status_mvc2, type: :wip)
+  def work_item_tasks_on_boards_feature_flag_enabled?
+    feature_flag_enabled_for_self_or_ancestor?(:work_item_tasks_on_boards, type: :wip)
   end
 
   def markdown_placeholders_feature_flag_enabled?
@@ -1177,9 +1152,21 @@ class Group < Namespace
     feature_flag_enabled_for_self_or_ancestor?(:glql_load_on_click, type: :ops)
   end
 
-  # overriden in EE
-  def supports_group_work_items?
-    false
+  def allow_iframes_in_markdown_feature_flag_enabled?
+    feature_flag_enabled_for_self_or_ancestor?(:allow_iframes_in_markdown, type: :wip)
+  end
+
+  def work_items_saved_views_enabled?(user = nil)
+    return true if feature_flag_enabled_for_self_or_ancestor?(:work_items_saved_views, type: :wip)
+
+    user.present? && Feature.enabled?(:work_items_saved_views_user, user)
+  end
+
+  def work_items_consolidated_list_enabled?(user = nil)
+    # work_item_planning_view is the feature flag used to determine whether the consolidated list is enabled or not
+    return true if feature_flag_enabled_for_self_or_ancestor?(:work_item_planning_view, type: :wip)
+
+    user.present? && Feature.enabled?(:work_items_consolidated_list_user, user)
   end
 
   # overriden in EE
@@ -1192,10 +1179,6 @@ class Group < Namespace
     false
   end
 
-  def create_group_level_work_items_feature_flag_enabled?
-    ::Feature.enabled?(:create_group_level_work_items, self, type: :wip) && supports_group_work_items?
-  end
-
   def supports_lock_on_merge?
     feature_flag_enabled_for_self_or_ancestor?(:enforce_locked_labels_on_merge, type: :ops)
   end
