@@ -17,6 +17,7 @@ class NamespaceSetting < ApplicationRecord
   ignore_column :third_party_ai_features_enabled, remove_with: '16.11', remove_after: '2024-04-18'
   ignore_column :code_suggestions, remove_with: '17.8', remove_after: '2024-05-16'
   ignore_column :job_token_policies_enabled, remove_with: '18.5', remove_after: '2025-09-13'
+  ignore_column :duo_agent_platform_request_count, remove_with: '18.9', remove_after: '2026-01-16'
 
   cascading_attr :math_rendering_limits_enabled, :resource_access_token_notify_inherited, :web_based_commit_signing_enabled
 
@@ -58,10 +59,20 @@ class NamespaceSetting < ApplicationRecord
   validate :validate_enterprise_bypass_expires_at, if: ->(record) {
     record.allow_enterprise_bypass_placeholder_confirmation? && (record.new_record? || record.will_save_change_to_enterprise_bypass_expires_at?)
   }
+  validates :step_up_auth_required_oauth_provider, presence: true, allow_nil: true
+  validates :step_up_auth_required_oauth_provider, inclusion: { in: ->(_) {
+    Gitlab::Auth::Oidc::StepUpAuthentication
+      .enabled_providers(scope: Gitlab::Auth::Oidc::StepUpAuthentication::SCOPE_NAMESPACE)
+      .map(&:to_s)
+  } }, allow_nil: true
+
+  validate :validate_step_up_auth_inheritance, if: :will_save_change_to_step_up_auth_required_oauth_provider?
 
   sanitizes! :default_branch_name
   nullify_if_blank :default_branch_name
 
+  nullify_if_blank :step_up_auth_required_oauth_provider
+
   before_validation :set_pipeline_variables_default_role, on: :create
 
   after_update :invalidate_namespace_descendants_cache, if: -> { saved_change_to_archived? }
@@ -87,6 +98,7 @@ class NamespaceSetting < ApplicationRecord
     math_rendering_limits_enabled
     lock_math_rendering_limits_enabled
     jwt_ci_cd_job_token_enabled
+    allow_personal_snippets
   ].freeze
 
   # matches the size set in the database constraint
@@ -102,6 +114,14 @@ class NamespaceSetting < ApplicationRecord
     NAMESPACE_SETTINGS_PARAMS
   end
 
+  def self.enterprise_bypass_min_date
+    Date.current.tomorrow.beginning_of_day
+  end
+
+  def self.enterprise_bypass_max_date
+    Date.current.advance(years: 1, days: -1).end_of_day
+  end
+
   def prevent_sharing_groups_outside_hierarchy
     return super if namespace.root?
 
@@ -158,24 +178,63 @@ class NamespaceSetting < ApplicationRecord
     allow_enterprise_bypass_placeholder_confirmation? && enterprise_bypass_expires_at.present? && enterprise_bypass_expires_at.future?
   end
 
+  # Returns the namespace_setting that provides the inherited step-up auth provider (excluding self)
+  # This is the base method that all other inheritance methods build upon
+  def step_up_auth_required_oauth_provider_inherited_namespace_setting
+    # Use traversal_ids for efficient ancestor lookup
+    # traversal_ids is an array like [root_id, parent_id, ..., current_id]
+    # We need to exclude self (current_id is the last element)
+    ancestor_ids = namespace.traversal_ids[0..-2] # All except the last element (self)
+
+    return if ancestor_ids.empty?
+
+    # Single optimized query using traversal_ids
+    # Order by position in traversal_ids array (root first, so most distant ancestor has precedence)
+    @step_up_auth_inherited_setting ||= self.class
+      .joins(:namespace)
+      .where(namespace_id: ancestor_ids)
+      .where.not(step_up_auth_required_oauth_provider: nil)
+      .order(Arel.sql("array_position(ARRAY[#{ancestor_ids.join(',')}]::bigint[], namespace_settings.namespace_id)"))
+      .includes(:namespace)
+      .first
+  end
+
+  # Returns the active/effective step-up auth provider, considering inheritance from parent groups
+  def step_up_auth_required_oauth_provider_from_self_or_inherited
+    step_up_auth_required_oauth_provider_inherited_namespace_setting&.step_up_auth_required_oauth_provider || step_up_auth_required_oauth_provider
+  end
+
   private
 
   def validate_enterprise_bypass_expires_at
     if enterprise_bypass_expires_at.blank?
-      errors.add(:enterprise_bypass_expires_at, s_('BulkImports|end date is required when bypass is enabled.'))
+      errors.add(:enterprise_bypass_expires_at, s_('BulkImports|You must enter a date when user confirmation is bypassed.'))
       return
     end
 
-    min_date = Date.current.tomorrow.beginning_of_day
-    max_date = Date.current.advance(years: 1, days: -1).end_of_day
+    min_date = self.class.enterprise_bypass_min_date
+    max_date = self.class.enterprise_bypass_max_date
 
     if enterprise_bypass_expires_at < min_date
-      errors.add(:enterprise_bypass_expires_at, s_('BulkImports|end date must be a future date.'))
+      errors.add(:enterprise_bypass_expires_at, s_('BulkImports|The date must be in the future.'))
     elsif enterprise_bypass_expires_at > max_date
-      errors.add(:enterprise_bypass_expires_at, s_('BulkImports|end date must not be more than a year in the future.'))
+      errors.add(:enterprise_bypass_expires_at, s_('BulkImports|The date must not be more than one year in the future.'))
     end
   end
 
+  def validate_step_up_auth_inheritance
+    # Use the base method to check inheritance and get parent info in one call
+    inherited_namespace_setting = step_up_auth_required_oauth_provider_inherited_namespace_setting
+    return unless inherited_namespace_setting
+
+    errors.add(:step_up_auth_required_oauth_provider,
+      format(
+        s_('GroupSettings|cannot be changed because it is inherited from parent group "%{parent_name}"'),
+        parent_name: inherited_namespace_setting.namespace.name
+      )
+    )
+  end
+
   def set_pipeline_variables_default_role
     return if Gitlab::CurrentSettings.pipeline_variables_default_allowed
 
