@@ -1,47 +1,87 @@
 # frozen_string_literal: true
 
 class SentNotification < ApplicationRecord
+  extend SuppressCompositePrimaryKeyWarning
+  include PartitionedTable
   include EachBatch
 
+  self.table_name = :p_sent_notifications
+
   INVALID_NOTEABLE = Class.new(StandardError)
-  # Email reply key is in the form: i_<id-64-bit>-k_<32-char-hex-key>-t_<timestamp-64-bit>
-  PARTITIONED_REPLY_KEY_REGEX = /i_(?<id>\d{1,19})-k_(?<reply_key>[a-f\d]{32})-t_(?<timestamp>\d{1,19})/
+  REPLY_KEY_BYTE_SIZE = 16
+  INTEGER_CONVERT_BASE = 36
+  BASE36_REGEX = /[0-9a-z]/
+  # Email reply key is in the form: <base36-partition-id>-<base36-reply-key>
+  PARTITIONED_REPLY_KEY_REGEX = /(?<partition>#{BASE36_REGEX}{1,4})-(?<reply_key>#{BASE36_REGEX}{25})/
   LEGACY_REPLY_KEY_REGEX = /(?<legacy_key>[a-f\d]{32})/
-  FULL_REPLY_KEY_REGEX = /((#{LEGACY_REPLY_KEY_REGEX})|(#{PARTITIONED_REPLY_KEY_REGEX}))/
+  FULL_REPLY_KEY_REGEX = /(?:(#{LEGACY_REPLY_KEY_REGEX})|(#{PARTITIONED_REPLY_KEY_REGEX}))/
+  PARTITION_DURATION = 2.months
+
+  attr_readonly :partition
+  attribute :partition, default: nil
 
   belongs_to :project
-  belongs_to :noteable, polymorphic: true # rubocop:disable Cop/PolymorphicAssociations
+  belongs_to :noteable, polymorphic: true # rubocop:disable Cop/PolymorphicAssociations -- Legacy definition
   belongs_to :recipient, class_name: "User"
   belongs_to :issue_email_participant
   belongs_to :namespace
 
   validates :recipient, :namespace_id, presence: true
-  validates :reply_key, presence: true, uniqueness: true
   validates :noteable_id, presence: true, unless: :for_commit?
   validates :commit_id, :project, presence: true, if: :for_commit?
   validates :in_reply_to_discussion_id, format: { with: /\A\h{40}\z/, allow_nil: true }
   validate :note_valid
 
   before_validation :ensure_sharding_key
-  before_create :ensure_created_at
+
+  partitioned_by :partition, strategy: :sliding_list,
+    next_partition_if: ->(active_partition) do
+      oldest_record_in_partition = select(:id, :created_at)
+        .for_partition(active_partition.value)
+        .order(:id)
+        .limit(1)
+        .take
+
+      oldest_record_in_partition.present? &&
+        oldest_record_in_partition.created_at < PARTITION_DURATION.ago
+    end,
+    detach_partition_if: ->(_) { false }
+
+  scope :for_partition, ->(partition) { where(partition: partition) }
+
+  before_save do
+    # attr_readonly still allows setting the column on insert
+    # This works because we have config.active_record.partial_inserts = true
+    clear_attribute_change(:partition)
+  end
 
   class << self
     def reply_key
-      SecureRandom.hex(16)
+      # Adding leading 0 to make the key size stable. 25 is the max we can get with 16 bytes
+      SecureRandom.random_number(2**(REPLY_KEY_BYTE_SIZE * 8)).to_s(INTEGER_CONVERT_BASE).rjust(25, '0')
     end
 
     def for(reply_key)
-      return find_by(reply_key: reply_key) if Feature.disabled?(:sent_notifications_partitioned_reply_key, :instance)
-
       matches = FULL_REPLY_KEY_REGEX.match(reply_key)
       return unless matches
 
-      if matches[:reply_key]
-        created_at_from_timestamp = Gitlab::Utils::TimeIntegerConverter.new(matches[:timestamp]).to_time
-        find_by(id: matches[:id], reply_key: matches[:reply_key], created_at: created_at_from_timestamp)
-      else
-        find_by(reply_key: matches[:legacy_key])
-      end
+      result = if matches[:reply_key]
+                 partition_result = where(
+                   partition: matches[:partition], reply_key: matches[:reply_key]
+                 ).to_a
+
+                 if partition_result.any?
+                   partition_result
+                 else
+                   where(reply_key: matches[:reply_key]).to_a
+                 end
+               else
+                 where(reply_key: matches[:legacy_key]).to_a
+               end
+
+      # We don't expect collisions, but in the unlikely case of one, behave like the record has been deleted
+      # Discussed in https://gitlab.com/gitlab-org/gitlab/-/issues/577844#note_2838135886
+      result.one? ? result.first : nil
     end
 
     def record(noteable, recipient_id, attrs = {})
@@ -56,7 +96,7 @@ class SentNotification < ApplicationRecord
       attrs.reverse_merge!(
         project: noteable.project,
         recipient_id: recipient_id,
-        reply_key: self.reply_key,
+        reply_key: reply_key,
 
         noteable_type: noteable.class.name,
         noteable_id: noteable_id,
@@ -77,14 +117,6 @@ class SentNotification < ApplicationRecord
     end
   end
 
-  def partitioned_reply_key
-    return reply_key if Feature.disabled?(:sent_notifications_partitioned_reply_key, :instance)
-
-    microseconds = Gitlab::Utils::TimeIntegerConverter.new(created_at).to_i
-
-    "i_#{id}-k_#{reply_key}-t_#{microseconds}"
-  end
-
   def unsubscribable?
     !(for_commit? || for_snippet?)
   end
@@ -121,20 +153,22 @@ class SentNotification < ApplicationRecord
 
     params[:external_author] = external_author if external_author.present?
 
-    klass.new(self.project,
-      self.recipient,
+    klass.new(project,
+      recipient,
       params
     ).execute
   end
 
-  private
+  def partitioned_reply_key
+    return reply_key unless persisted?
 
-  # TODO: Remove in 18.1 as this is only necessary while the default is loaded via the migration.
-  # See https://gitlab.com/gitlab-org/gitlab/-/merge_requests/186703#note_2432949624
-  def ensure_created_at
-    self.created_at = Time.current
+    encoded_partition = partition.to_s(INTEGER_CONVERT_BASE)
+
+    "#{encoded_partition}-#{reply_key}"
   end
 
+  private
+
   def ensure_sharding_key
     self.namespace_id = namespace_id_from_noteable
   end
@@ -146,7 +180,7 @@ class SentNotification < ApplicationRecord
     when MergeRequest, ProjectSnippet
       noteable.project.project_namespace_id
     when Commit
-      project&.project_namespace_id
+      project.project_namespace_id
     when WikiPage::Meta
       noteable.namespace_id || noteable.project.project_namespace_id
     else
@@ -154,29 +188,27 @@ class SentNotification < ApplicationRecord
       # for a new `noteable_type` is added.
       raise(
         INVALID_NOTEABLE,
-        _("%{noteable_type} is not supported") % { noteable_type: noteable_type }
+        format(_("%{noteable_type} is not supported"), noteable_type: noteable_type)
       )
     end
   end
 
   def reply_params
     {
-      noteable_type: self.noteable_type,
-      noteable_id: self.noteable_id,
-      commit_id: self.commit_id,
-      in_reply_to_discussion_id: self.in_reply_to_discussion_id
+      noteable_type: noteable_type,
+      noteable_id: noteable_id,
+      commit_id: commit_id,
+      in_reply_to_discussion_id: in_reply_to_discussion_id
     }
   end
 
   def note_valid
     note = create_reply('Test', dryrun: true)
+    return if note.valid?
 
-    unless note.valid?
-      self.errors.add(
-        :base, _("Note parameters are invalid: %{errors}") %
-          { errors: note.errors.full_messages.to_sentence }
-      )
-    end
+    errors.add(
+      :base, format(_("Note parameters are invalid: %{errors}"), errors: note.errors.full_messages.to_sentence)
+    )
   end
 end
 
