@@ -39,8 +39,13 @@ module Users
       expired_duo_enterprise_trial_widget: 27, # EE-only
       expired_trial_status_widget: 28, # EE-only
       namespace_user_cap_reached_alert: 29, # EE-only,
-      enable_duo_banner_duo_settings_page: 30, ## EE-only
-      enable_duo_banner_group_page: 31 # EE-only
+      # 30 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/202983
+      # 31 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/202983
+      # 32 removed in https://gitlab.com/gitlab-org/gitlab/-/merge_requests/214108
+      project_premium_message_callout: 33, # EE-only
+      repository_premium_message_callout: 34, # EE-only
+      mrs_premium_message_callout: 35, # EE-only
+      virtual_registry_permission_change_alert: 36 # EE-only
     }
 
     validates :group, presence: true
