@@ -20,7 +20,6 @@ class GlobalPolicy < BasePolicy
   end
 
   condition(:project_bot, scope: :user) { @user&.project_bot? }
-  condition(:migration_bot, scope: :user) { @user&.migration_bot? }
 
   condition(:service_account, scope: :user) { @user&.service_account? }
 
@@ -47,6 +46,10 @@ class GlobalPolicy < BasePolicy
     @user.unconfirmed_email.present? && !@user.unconfirmed_email.end_with?(User::NOREPLY_EMAIL_DOMAIN)
   end
 
+  condition(:project_studio_available, scope: :user, score: 0) do
+    ::Users::ProjectStudio.new(@user).enabled?
+  end
+
   rule { bot & ~bot_with_quick_actions_permitted }.policy do
     prevent :use_quick_actions
   end
@@ -86,7 +89,7 @@ class GlobalPolicy < BasePolicy
 
   rule { ~can?(:access_api) }.prevent :execute_graphql_mutation
 
-  rule { blocked | (internal & ~migration_bot & ~security_bot & ~security_policy_bot) }.policy do
+  rule { blocked | (internal & ~security_bot & ~security_policy_bot) }.policy do
     prevent :access_git
   end
 
@@ -180,6 +183,8 @@ class GlobalPolicy < BasePolicy
   rule { admin }.enable :use_project_statistics_filters
 
   rule { external_user }.prevent :create_snippet
+
+  rule { project_studio_available }.enable :enable_project_studio
 end
 
 GlobalPolicy.prepend_mod_with('GlobalPolicy')
