@@ -24,7 +24,6 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
   condition(:share_with_group_locked, scope: :subject) { @subject.share_with_group_lock? }
   condition(:parent_share_with_group_locked, scope: :subject) { @subject.parent&.share_with_group_lock? }
   condition(:can_change_parent_share_with_group_lock) { can?(:change_share_with_group_lock, @subject.parent) }
-  condition(:migration_bot, scope: :user) { @user&.migration_bot? }
   condition(:can_read_group_member) { can_read_group_member? }
 
   desc "User is a project bot"
@@ -128,20 +127,15 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     Feature.enabled?(:allow_guest_plus_roles_to_pull_packages, @subject.root_ancestor)
   end
 
-  condition(:archive_group_enabled, scope: :subject) do
-    Feature.enabled?(:archive_group, @subject.root_ancestor)
-  end
-
   condition(:archived, scope: :subject) { @subject.self_or_ancestors_archived? }
   condition(:group_scheduled_for_deletion, scope: :subject) { @subject.scheduled_for_deletion_in_hierarchy_chain? }
 
-  rule { archived & archive_group_enabled }.policy do
+  rule { archived }.policy do
     prevent :activate_group_member
     prevent :add_cluster
     prevent :admin_achievement
     prevent :admin_build
     prevent :admin_cluster
-    prevent :admin_group_member
     prevent :admin_issue
     prevent :admin_issue_board
     prevent :admin_issue_board_list
@@ -203,7 +197,6 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     prevent :create_incident
     prevent :admin_software_license_policy
     prevent :create_test_case
-    prevent :admin_ai_catalog_item
     prevent :set_issue_created_at
     prevent :set_issue_updated_at
     prevent :set_epic_created_at
@@ -246,7 +239,7 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     prevent :admin_compliance_pipeline_configuration
   end
 
-  rule { archived & archive_group_enabled & ~group_scheduled_for_deletion }.policy do
+  rule { archived & ~group_scheduled_for_deletion }.policy do
     prevent :delete_custom_emoji
     prevent :delete_o11y_settings
     prevent :destroy_issue
@@ -259,6 +252,10 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     enable :read_design_activity
   end
 
+  rule { can?(:read_group) & ~anonymous }.policy do
+    enable :create_saved_view
+  end
+
   rule { public_group }.policy do
     enable :read_group
     enable :read_package
@@ -287,6 +284,7 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     enable :admin_issue_board_list
     enable :admin_issue
     enable :admin_work_item
+    enable :destroy_issue
     enable :update_issue
     enable :read_confidential_issues
     enable :read_crm_organization
@@ -579,11 +577,6 @@ class GroupPolicy < Namespaces::GroupProjectNamespaceSharedPolicy
     prevent :update_runners_registration_token
   end
 
-  rule { migration_bot }.policy do
-    enable :read_resource_access_tokens
-    enable :destroy_resource_access_tokens
-  end
-
   rule { can?(:admin_group) | can?(:admin_runners) }.enable :admin_group_or_admin_runners
 
   rule { can?(:remove_group) | can?(:archive_group) }.enable :view_edit_page
