@@ -2,19 +2,7 @@
 
 class ProjectPolicy < BasePolicy
   include ArchivedAbilities
-
-  UPDATE_JOB_PERMISSIONS = [
-    :update_build, # TODO: remove usages of this permission
-    :play_job
-    # :retry_job,
-    # :unschedule_job,
-    # :manage_job_artifacts
-  ].freeze
-
-  CLEANUP_JOB_PERMISSIONS = [
-    :cancel_build,
-    :erase_build
-  ].freeze
+  include ::Ci::JobAbilities
 
   # https://docs.gitlab.com/18.2/ci/pipelines/settings/#change-which-users-can-view-your-pipelines
   desc "Project-based pipeline visibility enabled"
@@ -81,7 +69,7 @@ class ProjectPolicy < BasePolicy
   condition(:external_user) { user.external? }
 
   desc "Project is archived"
-  condition(:archived, scope: :subject, score: 0) { project_archived_or_ancestors_archived? }
+  condition(:archived, scope: :subject, score: 0) { project.self_or_ancestors_archived? }
 
   desc "Project user pipeline variables minimum override role"
   condition(:project_pipeline_override_role_owner) { project.ci_pipeline_variables_minimum_override_role == 'owner' }
@@ -166,6 +154,9 @@ class ProjectPolicy < BasePolicy
     public_project? || internal_access? || project_allowed_for_job_token_by_scope?
   end
 
+  desc "If the user is via CI job token and project visibility allows access"
+  condition(:job_token_repository) { job_token_access_allowed_to?(:repository) }
+
   desc "If the user is via CI job token and project container registry visibility allows access"
   condition(:job_token_container_registry) { job_token_access_allowed_to?(:container_registry) }
 
@@ -186,6 +177,16 @@ class ProjectPolicy < BasePolicy
     project.public? || project.internal?
   end
 
+  desc "If the pages is public"
+  condition(:public_pages) do
+    project.public_pages?
+  end
+
+  desc "If the pages is internal"
+  condition(:internal_pages) do
+    project.project_feature.pages_access_level == ProjectFeature::ENABLED
+  end
+
   with_scope :subject
   condition(:forking_allowed) do
     @subject.feature_available?(:forking, @user)
@@ -267,11 +268,7 @@ class ProjectPolicy < BasePolicy
   end
 
   condition(:push_repository_for_job_token_allowed) do
-    if ::Feature.enabled?(:allow_push_repository_for_job_token, @subject)
-      @user&.from_ci_job_token? && project.ci_push_repository_for_job_token_allowed? && @user.ci_job_token_scope.self_referential?(project)
-    else
-      false
-    end
+    @user&.from_ci_job_token? && project.ci_push_repository_for_job_token_allowed? && @user.ci_job_token_scope.self_referential?(project)
   end
 
   condition(:packages_disabled, scope: :subject) { !@subject.packages_enabled }
@@ -320,8 +317,6 @@ class ProjectPolicy < BasePolicy
     !Gitlab.config.terraform_state.enabled
   end
 
-  condition(:namespace_catalog_available) { namespace_catalog_available? }
-
   desc "User has either planner or reporter access"
   condition(:planner_or_reporter_access) do
     can?(:reporter_access) || can?(:planner_access)
@@ -333,7 +328,11 @@ class ProjectPolicy < BasePolicy
 
   # `:read_project` may be prevented in EE, but `:read_project_for_iids` should
   # not.
-  rule { guest | admin | organization_owner }.enable :read_project_for_iids
+  rule { guest | admin | organization_owner }.policy do
+    enable :read_project_for_iids
+    # We cannot use `guest_access` because that includes non-members on public projects
+    enable :read_pages_content
+  end
 
   rule { admin }.policy do
     enable :update_max_artifacts_size
@@ -397,17 +396,24 @@ class ProjectPolicy < BasePolicy
     enable :read_snippet
     enable :read_project_member
     enable :read_note
-    enable :create_project
     enable :create_issue
     enable :create_note
     enable :upload_file
     enable :read_cycle_analytics
     enable :award_emoji
-    enable :read_pages_content
     enable :read_release
     enable :read_analytics
     enable :read_insights
     enable :read_upload
+    enable :export_work_items
+  end
+
+  rule { internal_pages & ~anonymous & ~external_user }.policy do
+    enable :read_pages_content
+  end
+
+  rule { public_pages }.policy do
+    enable :read_pages_content
   end
 
   rule { can?(:planner_access) }.policy do
@@ -415,6 +421,7 @@ class ProjectPolicy < BasePolicy
     enable :admin_issue_board
     enable :admin_issue_board_list
     enable :update_issue
+    enable :destroy_issue
     enable :reopen_issue
     enable :admin_issue
     enable :admin_work_item
@@ -430,7 +437,12 @@ class ProjectPolicy < BasePolicy
     enable :admin_wiki
     enable :read_internal_note
     enable :read_merge_request
-    enable :export_work_items
+    enable :read_code
+    enable :download_code
+  end
+
+  rule { private_project & planner }.policy do
+    prevent :create_merge_request_in
   end
 
   rule { can?(:reporter_access) & can?(:create_issue) }.enable :create_incident
@@ -489,7 +501,6 @@ class ProjectPolicy < BasePolicy
     enable :read_external_emails
     enable :read_internal_note
     enable :read_grafana
-    enable :export_work_items
     enable :create_design
     enable :update_design
     enable :move_design
@@ -638,7 +649,6 @@ class ProjectPolicy < BasePolicy
     enable :update_deployment
     enable :read_cluster # Deprecated as certificate-based cluster integration (`Clusters::Cluster`).
     enable :read_cluster_agent
-    enable :use_k8s_proxies
     enable :create_release
     enable :update_release
     enable :destroy_release
@@ -657,7 +667,7 @@ class ProjectPolicy < BasePolicy
     enable :read_secure_files
     enable :update_sentry_issue
 
-    UPDATE_JOB_PERMISSIONS.each { |perm| enable(perm) }
+    enable(*all_job_update_abilities)
   end
 
   rule { can?(:developer_access) & user_confirmed? }.policy do
@@ -697,7 +707,7 @@ class ProjectPolicy < BasePolicy
     enable :admin_cluster
     enable :create_environment_terminal
     enable :destroy_release
-    enable :destroy_artifacts
+    enable :delete_job_artifact
     enable :admin_operations
     enable :admin_sentry
     enable :read_deploy_token
@@ -707,14 +717,8 @@ class ProjectPolicy < BasePolicy
     enable :create_freeze_period
     enable :read_freeze_period
     enable :update_freeze_period
-    enable :destroy_freeze_period
+    enable :delete_freeze_period
     enable :admin_feature_flags_client
-    enable :register_project_runners
-    enable :create_runners
-    enable :admin_runners
-    enable :read_runners
-    enable :read_runners_registration_token
-    enable :update_runners_registration_token
     enable :admin_project_google_cloud
     enable :admin_project_aws
     enable :admin_secure_files
@@ -733,6 +737,15 @@ class ProjectPolicy < BasePolicy
     enable :create_branch_rule
     enable :admin_protected_branch
     enable :admin_protected_environments
+
+    # doc/ci/runners/runners_scope.md#project-runners
+    # doc/user/permissions.md#cicd
+    enable :create_runners
+    enable :admin_runners
+    enable :read_runners
+    enable :read_runners_registration_token
+    enable :register_project_runners
+    enable :update_runners_registration_token
   end
 
   rule { can?(:manage_protected_tags) }.policy do
@@ -860,13 +873,13 @@ class ProjectPolicy < BasePolicy
   end
 
   rule { builds_disabled | repository_disabled }.policy do
-    UPDATE_JOB_PERMISSIONS.each { |perm| prevent(perm) }
-    CLEANUP_JOB_PERMISSIONS.each { |perm| prevent(perm) }
+    prevent(*all_job_write_abilities)
 
     prevent :read_build
     prevent :create_build
     prevent :admin_build
     prevent :destroy_build
+    prevent :admin_cicd_variables
 
     prevent :read_pipeline_schedule
     prevent :create_pipeline_schedule
@@ -981,6 +994,10 @@ class ProjectPolicy < BasePolicy
     enable :read_project
   end
 
+  rule { public_or_internal & job_token_repository }.policy do
+    enable :read_project
+  end
+
   rule { public_or_internal & job_token_builds }.policy do
     # this is additionally needed to download artifacts
     enable :read_commit_status
@@ -1018,7 +1035,6 @@ class ProjectPolicy < BasePolicy
     enable :read_release
     enable :download_wiki_code
     enable :read_cycle_analytics
-    enable :read_pages_content
     enable :read_analytics
     enable :read_insights
     enable :read_upload
@@ -1227,8 +1243,8 @@ class ProjectPolicy < BasePolicy
     enable :read_project_metadata
   end
 
-  rule { can?(:developer_access) & namespace_catalog_available }.policy do
-    enable :read_namespace_catalog
+  rule { can?(:read_project) & ~anonymous }.policy do
+    enable :create_saved_view
   end
 
   rule { public_project & model_registry_enabled }.policy do
@@ -1271,11 +1287,9 @@ class ProjectPolicy < BasePolicy
     enable :invite_project_members
   end
 
-  private
+  rule { can?(:read_project) }.enable :read_attestation
 
-  def project_archived_or_ancestors_archived?
-    project.archived? || (Feature.enabled?(:archive_group, project.root_ancestor) && project.self_or_ancestors_archived?)
-  end
+  private
 
   def team_member?
     return false if @user.nil?
@@ -1383,10 +1397,6 @@ class ProjectPolicy < BasePolicy
   def project
     @subject
   end
-
-  def namespace_catalog_available?
-    false
-  end
 end
 
 ProjectPolicy.prepend_mod_with('ProjectPolicy')
