@@ -289,7 +289,7 @@ module SystemNotes
 
     # Called when the status of a Task has changed
     #
-    # new_task  - TaskList::Item object.
+    # new_task  - Taskable::Item object.
     #
     # Example Note text:
     #
@@ -298,7 +298,7 @@ module SystemNotes
     # Returns the created Note object
     def change_task_status(new_task)
       status_label = new_task.complete? ? Taskable::COMPLETED : Taskable::INCOMPLETE
-      body = "marked the checklist item **#{new_task.source}** as #{status_label}"
+      body = "marked the checklist item **#{::GLFMMarkdown.escape_commonmark_inline(new_task.text)}** as #{status_label}"
 
       track_issue_event(:track_issue_description_changed_action)
 
@@ -485,7 +485,9 @@ module SystemNotes
         text = "#{self.class.cross_reference_note_prefix}%#{mentioned_in.to_reference(nil)}"
         notes.like_note_or_capitalized_note(text)
       else
-        gfm_reference = mentioned_in.gfm_reference(noteable.project || noteable.group)
+        from = noteable.project || noteable.try(:group) || noteable.try(:namespace)
+
+        gfm_reference = mentioned_in.gfm_reference(from)
         text = cross_reference_note_content(gfm_reference)
         notes.for_note_or_capitalized_note(text)
       end
