@@ -4,7 +4,7 @@ class FinalizeBackfillSnippetUserMentionsSnippetProjectId < Gitlab::Database::Mi
   milestone '18.2'
   disable_ddl_transaction!
 
-  restrict_gitlab_migration gitlab_schema: :gitlab_main_cell
+  restrict_gitlab_migration gitlab_schema: :gitlab_main_org
 
   def up
     ensure_batched_background_migration_is_finished(
