@@ -51,6 +51,19 @@ module API
         bad_request!('`updated_at` filter and `updated_at` sorting must be paired')
       end
 
+      def track_high_page_offset
+        return if params[:page] * params[:per_page] <= Plan.default.actual_limits.offset_pagination_limit
+
+        track_event(
+          'request_projects_api_high_offset',
+          user: current_user,
+          additional_properties: {
+            label: params[:per_page].to_s,
+            value: params[:page]
+          }
+        )
+      end
+
       def provided_order_is_not_updated_at?
         order_by_param = declared_params[:order_by]
 
@@ -86,7 +99,9 @@ module API
       end
 
       def immediately_delete_project_error(project)
-        if !project.marked_for_deletion_at?
+        if !Gitlab::CurrentSettings.allow_immediate_namespaces_deletion_for_user?(current_user)
+          '`permanently_remove` option is not permitted on this instance.'
+        elsif !project.self_deletion_scheduled?
           'Project must be marked for deletion first.'
         elsif project.full_path != params[:full_path]
           '`full_path` is incorrect. You must enter the complete path for the project.'
@@ -98,15 +113,14 @@ module API
 
         if permanently_remove
           error = immediately_delete_project_error(user_project)
-
           return render_api_error!(error, 400) if error
-        end
 
-        if permanently_remove
           destroy_conditionally!(user_project) do
             ::Projects::DestroyService.new(user_project, current_user, {}).async_execute
           end
 
+          return accepted!
+        elsif user_project.ancestor_scheduled_for_deletion?
           return accepted!
         end
 
@@ -213,7 +227,7 @@ module API
         projects = reorder_projects(projects) unless order_by_similarity?(allow_unauthorized: false)
         projects = apply_filters(projects)
 
-        records, options = paginate_with_strategies(projects, options[:request_scope]) do |projects|
+        records, options = paginate_with_strategies(projects, options[:request_scope], use_cursor: false) do |projects|
           projects, options = with_custom_attributes(projects, options)
 
           options = options.reverse_merge(
@@ -359,6 +373,7 @@ module API
       get feature_category: :groups_and_projects, urgency: :low do
         validate_projects_api_rate_limit!
         validate_updated_at_order_and_filter!
+        track_high_page_offset
         present_projects load_projects
       end
 
