@@ -6,22 +6,17 @@ module Gitlab
       module Chain
         class SetBuildSources < Chain::Base
           def perform!
-            return unless Feature.enabled?(:populate_and_use_build_source_table, project)
-
             command.pipeline_seed.stages.each do |stage|
-              stage.statuses.each do |build|
-                next unless build.instance_of?(::Ci::Build)
+              stage.statuses.each do |job|
+                job_source = if pipeline_execution_policy_build?(job)
+                               'pipeline_execution_policy'
+                             elsif scan_execution_policy_build?(job)
+                               'scan_execution_policy'
+                             else
+                               pipeline.source
+                             end
 
-                build_source = if pipeline_execution_policy_build?(build)
-                                 'pipeline_execution_policy'
-                               elsif scan_execution_policy_build?(build)
-                                 'scan_execution_policy'
-                               else
-                                 pipeline.source
-                               end
-
-                build.build_build_source(source: build_source,
-                  project_id: project.id)
+                job.build_job_source(source: job_source, project_id: project.id)
               end
             end
           end
