@@ -5,6 +5,7 @@
 module Gitlab
   module GonHelper
     include WebpackHelper
+    include ::Organizations::OrganizationHelper
 
     def add_gon_variables
       gon.api_version                   = 'v4'
@@ -19,8 +20,10 @@ module Gitlab
       gon.markdown_automatic_lists      = current_user&.markdown_automatic_lists
       gon.markdown_maintain_indentation = current_user&.markdown_maintain_indentation
       gon.math_rendering_limits_enabled = Gitlab::CurrentSettings.math_rendering_limits_enabled
-
-      add_browsersdk_tracking
+      gon.allow_immediate_namespaces_deletion =
+        Gitlab::CurrentSettings.allow_immediate_namespaces_deletion_for_user?(current_user)
+      gon.iframe_rendering_enabled      = Gitlab::CurrentSettings.iframe_rendering_enabled?
+      gon.iframe_rendering_allowlist    = Gitlab::CurrentSettings.iframe_rendering_allowlist
 
       # Sentry configurations for the browser client are done
       # via `Gitlab::CurrentSettings` from the Admin panel:
@@ -35,14 +38,15 @@ module Gitlab
       gon.recaptcha_sitekey      = Gitlab::CurrentSettings.recaptcha_site_key
       gon.gitlab_url             = Gitlab.config.gitlab.url
       gon.promo_url              = Gitlab::Routing.url_helpers.promo_url
-      gon.forum_url              = Gitlab::Saas.community_forum_url
-      gon.docs_url               = Gitlab::Saas.doc_url
+      gon.forum_url              = Gitlab.community_forum_url
+      gon.docs_url               = Gitlab.doc_url
       gon.revision               = Gitlab.revision
       gon.feature_category       = Gitlab::ApplicationContext.current_context_attribute(:feature_category).presence
       gon.gitlab_logo            = ActionController::Base.helpers.asset_path('gitlab_logo.png')
       gon.secure                 = Gitlab.config.gitlab.https
       gon.sprite_icons           = IconsHelper.sprite_icon_path
       gon.sprite_file_icons      = IconsHelper.sprite_file_icons_path
+      gon.illustrations_path     = IconsHelper.illustrations_path
       gon.emoji_sprites_css_path = universal_path_to_stylesheet('emoji_sprites')
       gon.emoji_backend_version  = Gitlab::Emoji::EMOJI_VERSION
       gon.gridstack_css_path     = universal_path_to_stylesheet('lazy_bundles/gridstack')
@@ -58,10 +62,12 @@ module Gitlab
       gon.uf_error_prefix        = ::Gitlab::Utils::ErrorMessage::UF_ERROR_PREFIX
       gon.pat_prefix             = Gitlab::CurrentSettings.current_application_settings.personal_access_token_prefix
       gon.keyboard_shortcuts_enabled = current_user ? current_user.keyboard_shortcuts_enabled : true
+      gon.broadcast_message_dismissal_path =
+        current_user ? Gitlab::Routing.url_helpers.broadcast_message_dismissals_path : nil
 
       gon.diagramsnet_url = Gitlab::CurrentSettings.diagramsnet_url if Gitlab::CurrentSettings.diagramsnet_enabled
 
-      if current_organization && Feature.enabled?(:ui_for_organizations, current_user)
+      if current_organization && ui_for_organizations_enabled?
         gon.current_organization = current_organization.slice(:id, :name, :full_path, :web_url, :avatar_url)
       end
 
@@ -88,21 +94,25 @@ module Gitlab
     # Initialize gon.features with any flags that should be
     # made globally available to the frontend
     def add_gon_feature_flags
-      push_frontend_feature_flag(:ui_for_organizations, current_user)
+      # Use `push_to_gon_attributes` directly since we have a computed feature flag with
+      # an opt-out in ui_for_organizations_enabled?
+      push_to_gon_attributes(:features, :ui_for_organizations, ui_for_organizations_enabled?)
       push_frontend_feature_flag(:organization_switching, current_user)
       push_frontend_feature_flag(:find_and_replace, current_user)
       # To be removed with https://gitlab.com/gitlab-org/gitlab/-/issues/399248
       push_frontend_feature_flag(:remove_monitor_metrics)
-      push_frontend_feature_flag(:work_item_view_for_issues)
-      push_frontend_feature_flag(:merge_request_dashboard, current_user, type: :beta)
       push_frontend_feature_flag(:new_project_creation_form, current_user, type: :wip)
       push_frontend_feature_flag(:work_items_client_side_boards, current_user)
-      push_frontend_feature_flag(:glql_work_items, current_user, type: :wip)
+      push_frontend_feature_flag(:glql_work_items, current_user)
       push_frontend_feature_flag(:glql_aggregation, current_user, type: :wip)
-      push_frontend_feature_flag(:whats_new_featured_carousel)
-      push_frontend_feature_flag(:extensible_reference_filters, current_user)
-      push_frontend_feature_flag(:global_topbar, current_user)
+      push_frontend_feature_flag(:glql_typescript, current_user, type: :wip)
       push_frontend_feature_flag(:paneled_view, current_user)
+      push_frontend_feature_flag(:archive_group)
+      push_frontend_feature_flag(:accessible_loading_button, current_user)
+      push_frontend_feature_flag(:allow_iframes_in_markdown, current_user)
+
+      # Expose the Project Studio user preference as if it were a feature flag
+      push_force_frontend_feature_flag(:project_studio_enabled, Users::ProjectStudio.new(current_user).enabled?)
     end
 
     # Exposes the state of a feature flag to the frontend code.
@@ -135,6 +145,12 @@ module Gitlab
       push_to_gon_attributes(:features, name, enabled)
     end
 
+    def push_application_setting(key)
+      return unless Gitlab::CurrentSettings.respond_to?(key)
+
+      gon.push({ key => Gitlab::CurrentSettings.public_send(key) }) # rubocop:disable GitlabSecurity/PublicSend
+    end
+
     def push_namespace_setting(key, object)
       return unless object&.namespace_settings.respond_to?(key)
 
@@ -159,15 +175,6 @@ module Gitlab
         ActionController::Base.helpers.image_path('no_avatar.png')).to_s
     end
 
-    def add_browsersdk_tracking
-      return unless Gitlab.com?
-
-      return if ENV['GITLAB_ANALYTICS_URL'].blank? || ENV['GITLAB_ANALYTICS_ID'].blank?
-
-      gon.analytics_url = ENV['GITLAB_ANALYTICS_URL']
-      gon.analytics_id = ENV['GITLAB_ANALYTICS_ID']
-    end
-
     # `::Current.organization` is only valid within the context of a request,
     # but it can be called from everywhere. So how do we avoid accidentally
     # calling it outside of the context of a request? We banned it with
