@@ -194,6 +194,7 @@ module Gitlab
         command :submit_review do |state = "reviewed"|
           next if params[:review_id]
 
+          pending_comments_count = quick_action_target.draft_notes.authored_by(current_user).count
           result = DraftNotes::PublishService.new(quick_action_target, current_user).execute
 
           reviewer_state = state.strip.presence
@@ -204,6 +205,12 @@ module Gitlab
                                                  [result[:message]]
                                                end
 
+          @additional_properties[:submit_review] = {
+            is_reviewer: quick_action_target.find_reviewer(current_user).present?.to_s,
+            pending_comments: pending_comments_count,
+            state: reviewer_state
+          }
+
           if reviewer_state === 'approve'
             approval_success = ::MergeRequests::ApprovalService
               .new(project: quick_action_target.project, current_user: current_user)
@@ -254,11 +261,30 @@ module Gitlab
           quick_action_target.persisted? && quick_action_target.eligible_for_approval_by?(current_user) && !quick_action_target.merged?
         end
         command :approve do
+          pending_comments_count = quick_action_target.draft_notes.authored_by(current_user).count
+
+          @execution_message[:approve] = []
+
+          if pending_comments_count > 0 && params[:review_id].blank?
+            result = DraftNotes::PublishService.new(quick_action_target, current_user).execute
+
+            @execution_message[:approve] = if result[:status] == :success
+                                             [_('Submitted the current review.')]
+                                           else
+                                             [result[:message]]
+                                           end
+          end
+
           success = ::MergeRequests::ApprovalService.new(project: quick_action_target.project, current_user: current_user).execute(quick_action_target)
 
           next unless success
 
-          @execution_message[:approve] = _('Approved the current merge request.')
+          @additional_properties[:approve] = {
+            is_reviewer: quick_action_target.find_reviewer(current_user).present?.to_s,
+            pending_comments: pending_comments_count
+          }
+
+          @execution_message[:approve] << _('Approved the current merge request.')
         end
 
         ########################################################################
@@ -276,6 +302,10 @@ module Gitlab
 
           next unless success
 
+          @additional_properties[:unapprove] = {
+            is_reviewer: quick_action_target.find_reviewer(current_user).present?.to_s
+          }
+
           @execution_message[:unapprove] = _('Unapproved the current merge request.')
         end
 
@@ -462,6 +492,35 @@ module Gitlab
               { reviewer_text: 'reviewer'.pluralize(removed_reviewers.size), reviewer_references: removed_reviewers.map(&:to_reference).to_sentence }
           end
         end
+
+        desc { _('Ship merge request (run pipeline and set auto-merge)') }
+        explanation { _('Ship merge request by creating a pipeline and set auto-merge.') }
+        types MergeRequest
+        condition do
+          ::MergeRequests::ShipMergeRequestWorker.allowed?(
+            merge_request: quick_action_target,
+            current_user: current_user)
+        end
+        command :ship do
+          ::MergeRequests::ShipMergeRequestWorker.perform_async(
+            current_user.id,
+            quick_action_target.id
+          )
+
+          @execution_message[:ship] = _('Actions to ship this merge request have been scheduled.')
+        end
+
+        desc { _('Run a pipeline') }
+        explanation { _('Run a new pipeline for this merge request') }
+        types MergeRequest
+        condition do
+          create_pipeline_service.allowed?(quick_action_target)
+        end
+        command :run_pipeline do
+          create_pipeline_service.execute_async(quick_action_target)
+
+          @execution_message[:run_pipeline] = _('New pipeline has been triggered and will appear shortly.')
+        end
       end
 
       def reviewer_users_sentence(users)
@@ -504,6 +563,13 @@ module Gitlab
         @merge_orchestration_service ||= ::MergeRequests::MergeOrchestrationService.new(project, current_user)
       end
 
+      def create_pipeline_service
+        @create_pipeline_service ||= ::MergeRequests::CreatePipelineService.new(
+          project: quick_action_target.project,
+          current_user: current_user,
+          params: { allow_duplicate: true })
+      end
+
       def preferred_auto_merge_strategy(merge_request)
         merge_orchestration_service.preferred_auto_merge_strategy(merge_request)
       end
