@@ -11,6 +11,10 @@ module QA
         end
       end
 
+      let(:issue) do
+        Resource::Issue.fabricate_via_api_unless_fips! { |issue| issue.project = project }
+      end
+
       before do
         Flow::Login.sign_in
       end
@@ -20,12 +24,12 @@ module QA
         :mobile,
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347989'
       ) do
-        resource, index_page_type = create_new_issue
+        created_issue = Resource::WorkItem.fabricate_via_browser_ui! { |issue| issue.project = project }
 
         Page::Project::Menu.perform(&:go_to_work_items)
 
-        index_page_type.perform do |index|
-          expect(index).to have_issue(resource)
+        Page::Project::WorkItem::Index.perform do |index|
+          expect(index).to have_issue(created_issue)
         end
       end
 
@@ -34,10 +38,9 @@ module QA
         :mobile,
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347967'
       ) do
-        resource, index_page_type, show_page_type = create_new_issue
-        resource.visit!
+        issue.visit!
 
-        show_page_type.perform do |issue_page|
+        Page::Project::WorkItem::Show.perform do |issue_page|
           issue_page.click_close_issue_button
 
           expect(issue_page).to have_reopen_issue_button
@@ -45,12 +48,12 @@ module QA
 
         Page::Project::Menu.perform(&:go_to_work_items)
 
-        index_page_type.perform do |index|
-          expect(index).not_to have_issue(resource)
+        Page::Project::WorkItem::Index.perform do |index|
+          expect(index).not_to have_issue(issue)
 
           index.click_closed_issues_tab
 
-          expect(index).to have_issue(resource)
+          expect(index).to have_issue(issue)
         end
       end
 
@@ -59,11 +62,11 @@ module QA
         'creates an issue and updates the description',
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/533855'
       ) do
-        resource, _, show_page_type = create_new_issue
         updated_description = "Updated issue description"
 
-        resource.visit!
-        show_page_type.perform do |show|
+        issue.visit!
+
+        Page::Project::WorkItem::Show.perform do |show|
           show.edit_description(updated_description)
 
           expect(show).to have_description(updated_description)
@@ -78,31 +81,15 @@ module QA
           'comments on an issue with an attachment',
           testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347946'
         ) do
-          resource, _, show_page_type = create_new_issue
-          resource.visit!
-          show_page_type.perform do |show|
+          issue.visit!
+
+          Page::Project::WorkItem::Show.perform do |show|
             show.comment('See attached image for scale', attachment: file_to_attach)
 
             expect(show.noteable_note_item.find("img[src$='#{png_file_name}']")).to be_visible
           end
         end
       end
-
-      def create_new_issue
-        project.visit!
-        Page::Project::Menu.perform(&:go_to_new_issue)
-        work_item_view_enabled = Page::Project::Issue::Show.perform(&:work_item_enabled?)
-        index_page_type = Page::Project::Issue::Index
-        show_page_type = Page::Project::WorkItem::Show
-
-        resource = if work_item_view_enabled
-                     Resource::WorkItem.fabricate_via_browser_ui! { |work_item| work_item.project = project }
-                   else
-                     Resource::Issue.fabricate_via_browser_ui! { |issue| issue.project = project }
-                   end
-
-        [resource, index_page_type, show_page_type]
-      end
     end
   end
 end
