@@ -30,8 +30,8 @@ module QA
         end
 
         if Runtime::Env.personal_access_tokens_disabled?
-          Resource::Issue.fabricate_via_browser_ui! do |issue|
-            issue.project = project
+          Resource::WorkItem.fabricate_via_browser_ui! do |work_item|
+            work_item.project = project
           end.visit!
         else
           create(:issue, project: project).visit!
@@ -40,10 +40,7 @@ module QA
 
       it 'mentions another user in an issue',
         testcase: 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347988' do
-        work_item_enabled = Page::Project::Issue::Show.perform(&:work_item_enabled?)
-        page_type = work_item_enabled ? Page::Project::WorkItem::Show : Page::Project::Issue::Show
-
-        page_type.perform do |show|
+        Page::Project::WorkItem::Show.perform do |show|
           at_username = "@#{user.username}"
 
           show.select_all_activities_filter
