@@ -2,9 +2,8 @@
 
 module QA
   RSpec.describe 'Package', :object_storage, feature_category: :package_registry, quarantine: {
-    issue: 'https://gitlab.com/gitlab-org/gitlab/-/issues/455304',
-    only: { condition: -> { ENV['QA_RUN_TYPE']&.match?('gdk-instance') } },
-    type: :investigating
+    issue: 'https://gitlab.com/gitlab-org/quality/test-failure-issues/-/issues/14565',
+    type: :flaky
   } do
     describe 'NuGet group level endpoint', :external_api_calls do
       using RSpec::Parameterized::TableSyntax
@@ -64,9 +63,9 @@ module QA
       end
 
       where(:case_name, :authentication_token_type, :token_name, :testcase) do
-        'using personal access token' | :personal_access_token | 'Personal access token' | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347597'
-        'using ci job token'          | :ci_job_token          | 'CI Job Token'          | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347595'
-        'using group deploy token'    | :group_deploy_token    | 'Deploy Token'          | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/347596'
+        'using personal access token' | :personal_access_token | 'Personal access token' | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/479652'
+        'using ci job token'          | :ci_job_token          | 'CI Job Token'          | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/479654'
+        'using group deploy token'    | :group_deploy_token    | 'Deploy Token'          | 'https://gitlab.com/gitlab-org/gitlab/-/quality/test_cases/479653'
       end
 
       with_them do
