@@ -164,9 +164,9 @@ RSpec.describe UserSettings::PersonalAccessTokensController, feature_category: :
   end
 
   describe '#new' do
-    context 'when fine_grained_personal_access_tokens feature flag is disabled' do
+    context 'when granular_personal_access_tokens feature flag is disabled' do
       before do
-        stub_feature_flags(fine_grained_personal_access_tokens: false)
+        stub_feature_flags(granular_personal_access_tokens: false)
       end
 
       it 'returns 404' do
@@ -178,7 +178,7 @@ RSpec.describe UserSettings::PersonalAccessTokensController, feature_category: :
 
     context 'when feature flag is enabled' do
       before do
-        stub_feature_flags(fine_grained_personal_access_tokens: true)
+        stub_feature_flags(granular_personal_access_tokens: true)
       end
 
       it 'renders the new template' do
