@@ -3,6 +3,7 @@
 FactoryBot.define do
   factory :package_file, class: 'Packages::PackageFile' do
     package { association(:generic_package) }
+    project { package.project }
 
     file_name { 'somefile.txt' }
 
@@ -13,13 +14,17 @@ FactoryBot.define do
     end
 
     after(:build) do |package_file, evaluator|
-      package_file.file = fixture_file_upload(evaluator.file_fixture)
+      package_file.file = fixture_file_upload(evaluator.file_fixture) if evaluator.file_fixture
     end
 
     trait :pending_destruction do
       status { :pending_destruction }
     end
 
+    trait :processing do
+      status { :processing }
+    end
+
     factory :conan_package_file do
       package { association(:conan_package, without_package_files: true) }
 
