@@ -6,7 +6,12 @@ FactoryBot.define do
     build factory: [:ci_build, :success]
     predicate_kind { :provenance }
     predicate_type { "https://slsa.dev/provenance/v1" }
-    subject_digest { Digest::SHA256.hexdigest("abc") }
+    sequence(:subject_digest) { |n| Digest::SHA256.hexdigest("attestation-#{n}") }
     file { fixture_file_upload('spec/fixtures/supply_chain/attestation.json') }
+    predicate_file { fixture_file_upload('spec/fixtures/supply_chain/predicate.json') }
+
+    trait :with_error_status do
+      status { 'error' }
+    end
   end
 end
