@@ -3,6 +3,8 @@
 require 'spec_helper'
 
 RSpec.describe 'Issues > User creates issue by email', feature_category: :team_planning do
+  include Spec::Support::Helpers::ModalHelpers
+
   let_it_be(:user) { create(:user) }
   let_it_be(:project) { create(:project, :public) }
 
@@ -26,11 +28,14 @@ RSpec.describe 'Issues > User creates issue by email', feature_category: :team_p
         stub_incoming_email_setting(enabled: true, address: "p+%{key}@gl.ab")
 
         visit project_issues_path(project)
-        click_button('Email a new issue')
+
+        find_by_testid('work-items-list-more-actions-dropdown').click
+
+        click_button('Email work item to this project')
       end
 
       it 'click the button to show modal for the new email' do
-        page.within '#issuable-email-modal' do
+        within_modal do
           email = project.new_issuable_address(user, 'issue')
 
           expect(page.find('input[type="text"]').value).to eq email
