@@ -22,12 +22,13 @@ RSpec.describe 'User comments on a diff', :js, feature_category: :code_review_wo
   let(:user) { create(:user) }
 
   before do
+    # -- temporary Project Studio rollout
+    skip 'Test not applicable in classic UI' unless Users::ProjectStudio.enabled_for_user?(user)
+
     project.add_maintainer(user)
-    enable_project_studio!(user)
     sign_in(user)
 
     visit(diffs_project_merge_request_path(project, merge_request))
-    dismiss_welcome_banner_if_present(page)
     wait_for_requests
   end
 
@@ -264,7 +265,6 @@ RSpec.describe 'User comments on a diff', :js, feature_category: :code_review_wo
 
       # Making sure it's not a Front-end cache.
       visit(diffs_project_merge_request_path(project, merge_request))
-      dismiss_welcome_banner_if_present(page)
       wait_for_requests
 
       expect(page).to have_button('Apply suggestion').twice
@@ -435,7 +435,6 @@ RSpec.describe 'User comments on a diff', :js, feature_category: :code_review_wo
       wait_for_requests
 
       visit(project_merge_request_path(project, merge_request))
-      dismiss_welcome_banner_if_present(page)
 
       wait_for_requests
     end
