@@ -6,9 +6,9 @@ export const mockCiLintJobs = [
     allowFailure: false,
     tags: [],
     when: 'on_success',
-    only: { refs: ['branches', 'tags'], __typename: 'CiJobLimitType' },
+    only: { refs: ['branches', 'tags'], __typename: 'CiConfigJobRestriction' },
     except: null,
-    needs: [{ name: 'test', __typename: 'CiConfigNeed' }],
+    needs: [],
     __typename: 'CiConfigJobV2',
     name: 'job_test_1',
     script: ['echo "test 1"'],
@@ -24,9 +24,9 @@ export const mockCiLintJobs = [
     allowFailure: false,
     tags: [],
     when: 'on_success',
-    only: { refs: ['branches', 'tags'], __typename: 'CiJobLimitType' },
+    only: { refs: ['branches', 'tags'], __typename: 'CiConfigJobRestriction' },
     except: null,
-    needs: [{ name: 'test', __typename: 'CiConfigNeed' }],
+    needs: [],
     __typename: 'CiConfigJobV2',
   },
   {
@@ -39,9 +39,12 @@ export const mockCiLintJobs = [
     allowFailure: false,
     tags: [],
     when: 'on_success',
-    only: { refs: ['branches', 'tags'], __typename: 'CiJobLimitType' },
+    only: { refs: ['branches', 'tags'], __typename: 'CiConfigJobRestriction' },
     except: null,
-    needs: [{ name: 'test', __typename: 'CiConfigNeed' }],
+    needs: [
+      { name: 'job_test_1', __typename: 'CiConfigNeed' },
+      { name: 'job_test_2', __typename: 'CiConfigNeed' },
+    ],
     __typename: 'CiConfigJobV2',
   },
 ];
