@@ -70,14 +70,14 @@ describe('Pipeline header', () => {
   const findLoadingIcon = () => wrapper.findComponent(GlLoadingIcon);
   const findBadges = () => wrapper.findComponent(HeaderBadges);
   const findHeaderActions = () => wrapper.findComponent(HeaderActions);
+  const findCreatedStatus = () => wrapper.findByTestId('pipeline-created-status');
   const findCreatedTimeAgo = () => wrapper.findByTestId('pipeline-created-time-ago');
   const findFinishedTimeAgo = () => wrapper.findByTestId('pipeline-finished-time-ago');
-  const findFinishedCreatedTimeAgo = () =>
-    wrapper.findByTestId('pipeline-finished-created-time-ago');
-  const findPipelineName = () => wrapper.findByTestId('pipeline-name');
-  const findCommitTitle = () => wrapper.findByTestId('pipeline-commit-title');
+  const findPipelineId = () => wrapper.findByTestId('pipeline-id');
+  const findPipelineTitle = () => wrapper.findByTestId('pipeline-title');
   const findTotalJobs = () => wrapper.findByTestId('total-jobs');
   const findCommitLink = () => wrapper.findByTestId('commit-link');
+  const findCommitTitle = () => wrapper.findByTestId('commit-title');
   const findCommitCopyButton = () => wrapper.findByTestId('commit-copy-sha');
   const findPipelineRunningText = () => wrapper.findByTestId('pipeline-running-text').text();
   const findPipelineRefText = () => wrapper.findByTestId('pipeline-ref-text').text();
@@ -90,32 +90,32 @@ describe('Pipeline header', () => {
 
   const defaultHandlers = [
     [getPipelineDetailsQuery, successHandler],
+    [deletePipelineMutation, deleteMutationHandlerSuccess],
     [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
   ];
 
-  const defaultProvideOptions = {
-    identityVerificationRequired: false,
-    identityVerificationPath: '#',
-    pipelineIid: 1,
-    pipelineId: 100,
-    paths: {
-      pipelinesPath: '/namespace/my-project/-/pipelines',
-      fullProject: '/namespace/my-project',
-    },
-  };
-
-  const createMockApolloProvider = (handlers) => {
-    return createMockApollo(handlers);
-  };
-
-  const createComponent = (handlers = defaultHandlers) => {
-    apolloProvider = createMockApolloProvider(handlers);
+  const createComponent = ({ handlers = defaultHandlers, provide = {} } = {}) => {
+    apolloProvider = createMockApollo(handlers);
 
     wrapper = shallowMountExtended(PipelineHeader, {
       provide: {
-        ...defaultProvideOptions,
+        identityVerificationRequired: false,
+        identityVerificationPath: '#',
+        pipelineIid: 1,
+        pipelineId: 100,
+        paths: {
+          pipelinesPath: '/namespace/my-project/-/pipelines',
+          fullProject: '/namespace/my-project',
+        },
+        ...provide,
+      },
+      stubs: {
+        GlSprintf,
+        TimeAgoTooltip: {
+          props: ['time'],
+          template: '<span>{{time}}</span>',
+        },
       },
-      stubs: { GlSprintf },
       apolloProvider,
     });
 
@@ -144,7 +144,7 @@ describe('Pipeline header', () => {
     });
 
     it('displays pipeline name', () => {
-      expect(findPipelineName().text()).toBe('Build pipeline');
+      expect(findPipelineTitle().text()).toBe('Build pipeline');
     });
 
     it('displays total jobs', () => {
@@ -162,6 +162,32 @@ describe('Pipeline header', () => {
       expect(findCommitLink().text()).toBe(pipeline.commit.shortId);
     });
 
+    describe('when ci_show_pipeline_name_instead_of_commit_title is disabled', () => {
+      it('displays commit title', () => {
+        expect(findCommitTitle().exists()).toBe(false);
+      });
+    });
+
+    describe('when ci_show_pipeline_name_instead_of_commit_title is enabled', () => {
+      it('displays commit title', async () => {
+        await createComponent({
+          provide: {
+            glFeatures: {
+              ciShowPipelineNameInsteadOfCommitTitle: true,
+            },
+          },
+        });
+
+        const {
+          data: {
+            project: { pipeline },
+          },
+        } = pipelineHeaderSuccess;
+
+        expect(findCommitTitle().text()).toBe(pipeline.commit.title);
+      });
+    });
+
     it('copies the full commit ID', () => {
       const {
         data: {
@@ -177,10 +203,7 @@ describe('Pipeline header', () => {
     });
 
     it('passes pipeline prop to HeaderBadges component', async () => {
-      await createComponent([
-        [getPipelineDetailsQuery, successHandler],
-        [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-      ]);
+      await createComponent();
 
       expect(findBadges().props('pipeline')).toEqual(pipelineHeaderSuccess.data.project.pipeline);
     });
@@ -190,13 +213,7 @@ describe('Pipeline header', () => {
     });
 
     it('displays pipeline user link with required user popover attributes', () => {
-      const {
-        data: {
-          project: {
-            pipeline: { user },
-          },
-        },
-      } = pipelineHeaderSuccess;
+      const { user } = pipelineHeaderSuccess.data.project.pipeline;
 
       const userId = getIdFromGraphQLId(user.id).toString();
 
@@ -207,29 +224,88 @@ describe('Pipeline header', () => {
     });
   });
 
-  describe('without pipeline name', () => {
-    it('displays commit title', async () => {
-      await createComponent([
-        [getPipelineDetailsQuery, runningHandler],
-        [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-      ]);
+  describe('without pipeline name (from workflow:name)', () => {
+    describe('when ci_show_pipeline_name_instead_of_commit_title is disabled', () => {
+      it('displays commit title', async () => {
+        await createComponent({
+          handlers: [
+            [getPipelineDetailsQuery, runningHandler],
+            [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+          ],
+        });
 
-      const expectedTitle = pipelineHeaderSuccess.data.project.pipeline.commit.title;
+        const commitTitle = pipelineHeaderRunning.data.project.pipeline.commit.title;
 
-      expect(findPipelineName().exists()).toBe(false);
-      expect(findCommitTitle().text()).toBe(expectedTitle);
+        expect(findPipelineId().exists()).toBe(false);
+        expect(findPipelineTitle().text()).toBe(commitTitle);
+      });
+    });
+
+    describe('when ci_show_pipeline_name_instead_of_commit_title is enabled', () => {
+      it('shows a pipeline id', async () => {
+        await createComponent({
+          provide: {
+            glFeatures: { ciShowPipelineNameInsteadOfCommitTitle: true },
+          },
+          handlers: [
+            [getPipelineDetailsQuery, runningHandler],
+            [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+          ],
+        });
+
+        const id = getIdFromGraphQLId(pipelineHeaderRunning.data.project.pipeline.id);
+
+        // only id is shown
+        expect(findPipelineId().text()).toBe(`#${id}`);
+        expect(findPipelineTitle().exists()).toBe(false);
+      });
     });
   });
 
-  describe('finished pipeline', () => {
-    it('displays finished time and created time', async () => {
+  describe('pipeline created/finished status', () => {
+    const { createdAt, finishedAt, user } = pipelineHeaderSuccess.data.project.pipeline;
+
+    it.each`
+      createdAt    | finishedAt    | user    | expectedText
+      ${createdAt} | ${finishedAt} | ${user} | ${`Created ${createdAt} by ${user.name}, finished ${finishedAt}`}
+      ${createdAt} | ${finishedAt} | ${null} | ${`Created ${createdAt}, finished ${finishedAt}`}
+      ${createdAt} | ${null}       | ${user} | ${`Created ${createdAt} by ${user.name}`}
+      ${createdAt} | ${null}       | ${null} | ${`Created ${createdAt}`}
+      ${null}      | ${finishedAt} | ${user} | ${`Created by ${user.name}, finished ${finishedAt}`}
+      ${null}      | ${finishedAt} | ${null} | ${`Finished ${finishedAt}`}
+      ${null}      | ${null}       | ${user} | ${`Created by ${user.name}`}
+      ${null}      | ${null}       | ${null} | ${''}
+    `('displays "$expectedText"', async ({ expectedText, ...pipeline }) => {
+      successHandler.mockResolvedValueOnce({
+        data: {
+          project: {
+            id: 'gid://gitlab/Project/1',
+            pipeline: {
+              ...pipelineHeaderSuccess.data.project.pipeline,
+              ...pipeline,
+            },
+          },
+        },
+      });
+
       await createComponent();
 
-      expect(findFinishedTimeAgo().exists()).toBe(true);
-      expect(findFinishedCreatedTimeAgo().exists()).toBe(true);
+      expect(findCreatedStatus().text()).toMatchInterpolatedText(expectedText);
+
+      if (pipeline.createdAt) {
+        expect(findCreatedTimeAgo().props('time')).toBe(pipeline.createdAt);
+      } else {
+        expect(findCreatedTimeAgo().exists()).toBe(false);
+      }
+
+      if (pipeline.finishedAt) {
+        expect(findFinishedTimeAgo().props('time')).toBe(pipeline.finishedAt);
+      } else {
+        expect(findFinishedTimeAgo().exists()).toBe(false);
+      }
     });
 
-    it('displays pipeline duartion text', async () => {
+    it('displays pipeline duration text', async () => {
       await createComponent();
 
       expect(findPipelineDuration().text()).toBe(
@@ -240,15 +316,12 @@ describe('Pipeline header', () => {
 
   describe('running pipeline', () => {
     beforeEach(() => {
-      return createComponent([
-        [getPipelineDetailsQuery, runningHandler],
-        [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-      ]);
-    });
-
-    it('does not display finished time ago', () => {
-      expect(findFinishedTimeAgo().exists()).toBe(false);
-      expect(findFinishedCreatedTimeAgo().exists()).toBe(false);
+      return createComponent({
+        handlers: [
+          [getPipelineDetailsQuery, runningHandler],
+          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+        ],
+      });
     });
 
     it('does not display pipeline duration text', () => {
@@ -258,18 +331,16 @@ describe('Pipeline header', () => {
     it('displays pipeline running text', () => {
       expect(findPipelineRunningText()).toBe('In progress, queued for 3,600 seconds');
     });
-
-    it('displays created time ago', () => {
-      expect(findCreatedTimeAgo().exists()).toBe(true);
-    });
   });
 
   describe('running pipeline with duration', () => {
     beforeEach(() => {
-      return createComponent([
-        [getPipelineDetailsQuery, runningHandlerWithDuration],
-        [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-      ]);
+      return createComponent({
+        handlers: [
+          [getPipelineDetailsQuery, runningHandlerWithDuration],
+          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+        ],
+      });
     });
 
     it('does not display pipeline duration text', () => {
@@ -279,11 +350,13 @@ describe('Pipeline header', () => {
 
   describe('actions', () => {
     it('passes correct props to the header actions component', async () => {
-      await createComponent([
-        [getPipelineDetailsQuery, failedHandler],
-        [retryPipelineMutation, retryMutationHandlerSuccess],
-        [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-      ]);
+      await createComponent({
+        handlers: [
+          [getPipelineDetailsQuery, failedHandler],
+          [retryPipelineMutation, retryMutationHandlerSuccess],
+          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+        ],
+      });
 
       expect(findHeaderActions().props()).toEqual({
         isCanceling: false,
@@ -295,11 +368,13 @@ describe('Pipeline header', () => {
 
     describe('retry action', () => {
       beforeEach(() => {
-        return createComponent([
-          [getPipelineDetailsQuery, failedHandler],
-          [retryPipelineMutation, retryMutationHandlerSuccess],
-          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-        ]);
+        return createComponent({
+          handlers: [
+            [getPipelineDetailsQuery, failedHandler],
+            [retryPipelineMutation, retryMutationHandlerSuccess],
+            [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+          ],
+        });
       });
 
       it('should call retryPipeline Mutation with pipeline id', async () => {
@@ -321,11 +396,13 @@ describe('Pipeline header', () => {
 
     describe('retry action failed', () => {
       beforeEach(() => {
-        return createComponent([
-          [getPipelineDetailsQuery, failedHandler],
-          [retryPipelineMutation, retryMutationHandlerFailed],
-          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-        ]);
+        return createComponent({
+          handlers: [
+            [getPipelineDetailsQuery, failedHandler],
+            [retryPipelineMutation, retryMutationHandlerFailed],
+            [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+          ],
+        });
       });
 
       it('should display error message on failure', async () => {
@@ -352,11 +429,13 @@ describe('Pipeline header', () => {
     describe('cancel action', () => {
       describe('with permissions', () => {
         it('should call cancelPipeline Mutation with pipeline id', async () => {
-          await createComponent([
-            [getPipelineDetailsQuery, runningHandler],
-            [cancelPipelineMutation, cancelMutationHandlerSuccess],
-            [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-          ]);
+          await createComponent({
+            handlers: [
+              [getPipelineDetailsQuery, runningHandler],
+              [cancelPipelineMutation, cancelMutationHandlerSuccess],
+              [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+            ],
+          });
 
           clickActionButton('cancelPipeline', pipelineHeaderRunning.data.project.pipeline.id);
 
@@ -374,11 +453,13 @@ describe('Pipeline header', () => {
         });
 
         it('should display error message on failure', async () => {
-          await createComponent([
-            [getPipelineDetailsQuery, runningHandler],
-            [cancelPipelineMutation, cancelMutationHandlerFailed],
-            [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-          ]);
+          await createComponent({
+            handlers: [
+              [getPipelineDetailsQuery, runningHandler],
+              [cancelPipelineMutation, cancelMutationHandlerFailed],
+              [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+            ],
+          });
 
           clickActionButton('cancelPipeline', pipelineHeaderRunning.data.project.pipeline.id);
 
@@ -391,11 +472,7 @@ describe('Pipeline header', () => {
 
     describe('delete action', () => {
       it('should call deletePipeline Mutation with pipeline id when modal is submitted', async () => {
-        await createComponent([
-          [getPipelineDetailsQuery, successHandler],
-          [deletePipelineMutation, deleteMutationHandlerSuccess],
-          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-        ]);
+        await createComponent();
 
         clickActionButton('deletePipeline', pipelineHeaderSuccess.data.project.pipeline.id);
 
@@ -412,11 +489,13 @@ describe('Pipeline header', () => {
       });
 
       it('should display error message on failure', async () => {
-        await createComponent([
-          [getPipelineDetailsQuery, successHandler],
-          [deletePipelineMutation, deleteMutationHandlerFailed],
-          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-        ]);
+        await createComponent({
+          handlers: [
+            [getPipelineDetailsQuery, successHandler],
+            [deletePipelineMutation, deleteMutationHandlerFailed],
+            [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+          ],
+        });
 
         clickActionButton('deletePipeline', pipelineHeaderSuccess.data.project.pipeline.id);
 
@@ -426,11 +505,13 @@ describe('Pipeline header', () => {
       });
 
       it('delete button loading state should reset on error', async () => {
-        await createComponent([
-          [getPipelineDetailsQuery, successHandler],
-          [deletePipelineMutation, deleteMutationHandlerFailed],
-          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-        ]);
+        await createComponent({
+          handlers: [
+            [getPipelineDetailsQuery, successHandler],
+            [deletePipelineMutation, deleteMutationHandlerFailed],
+            [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+          ],
+        });
 
         clickActionButton('deletePipeline', pipelineHeaderSuccess.data.project.pipeline.id);
 
@@ -446,10 +527,12 @@ describe('Pipeline header', () => {
 
     describe('subscription', () => {
       it('calls subscription with correct variables', async () => {
-        await createComponent([
-          [getPipelineDetailsQuery, successHandler],
-          [pipelineHeaderStatusUpdatedSubscription, subscriptionHandler],
-        ]);
+        await createComponent({
+          handlers: [
+            [getPipelineDetailsQuery, successHandler],
+            [pipelineHeaderStatusUpdatedSubscription, subscriptionHandler],
+          ],
+        });
 
         const {
           data: {
@@ -463,11 +546,13 @@ describe('Pipeline header', () => {
       });
 
       it('does not make redundant subscription calls for refetches', async () => {
-        await createComponent([
-          [getPipelineDetailsQuery, runningHandler],
-          [cancelPipelineMutation, cancelMutationHandlerSuccess],
-          [pipelineHeaderStatusUpdatedSubscription, subscriptionHandler],
-        ]);
+        await createComponent({
+          handlers: [
+            [getPipelineDetailsQuery, runningHandler],
+            [cancelPipelineMutation, cancelMutationHandlerSuccess],
+            [pipelineHeaderStatusUpdatedSubscription, subscriptionHandler],
+          ],
+        });
 
         expect(subscriptionHandler).toHaveBeenCalledTimes(1);
 
@@ -509,10 +594,12 @@ describe('Pipeline header', () => {
     });
 
     it('updates favicon when pipeline status changes', async () => {
-      await createComponent([
-        [getPipelineDetailsQuery, runningHandler],
-        [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
-      ]);
+      await createComponent({
+        handlers: [
+          [getPipelineDetailsQuery, runningHandler],
+          [pipelineHeaderStatusUpdatedSubscription, subscriptionNullHandler],
+        ],
+      });
 
       const {
         data: {
