@@ -212,6 +212,7 @@ export const createMockPipelineStageJobs = () => ({
               group: 'success',
               hasDetails: true,
               icon: 'status_success',
+              label: 'passed',
               tooltip: 'passed',
             },
             name: 'test_job',
@@ -238,6 +239,7 @@ export const createMockPipelineStageJobs = () => ({
               hasDetails: true,
               icon: 'status_failed',
               tooltip: 'failed',
+              label: 'failed',
             },
             name: 'test_job_2',
             scheduled: false,
