@@ -639,6 +639,30 @@ describe('GfmAutoComplete', () => {
         },
       ]);
     });
+
+    it('should include composite_identity_enforced field', () => {
+      expect(
+        membersBeforeSave([
+          {
+            username: 'my-user',
+            name: 'My User',
+            avatar_url: './users.jpg',
+            type: 'User',
+            composite_identity_enforced: true,
+          },
+        ]),
+      ).toEqual([
+        {
+          username: 'my-user',
+          avatarTag:
+            '<img src="./users.jpg" alt="my-user" class="avatar  avatar-inline s24 gl-mr-2"/>',
+          title: 'My User',
+          search: 'MyUser my-user',
+          icon: '',
+          compositeIdentityEnforced: true,
+        },
+      ]);
+    });
   });
 
   describe('Issues.insertTemplateFunction', () => {
@@ -758,6 +782,37 @@ describe('GfmAutoComplete', () => {
         );
       });
 
+      describe('when compositeIdentityEnforced is true', () => {
+        it('should add composite identity enforced badge', () => {
+          const result = GfmAutoComplete.Members.templateFunction({
+            avatarTag: 'IMG',
+            username: 'my-user',
+            title: '',
+            icon: '',
+            availabilityStatus: '',
+            compositeIdentityEnforced: true,
+          });
+          expect(result).toContain('IMG my-user');
+          expect(result).toContain('Agent');
+          expect(result).toContain('gl-badge');
+        });
+      });
+
+      describe('when compositeIdentityEnforced is false', () => {
+        it('should not add composite identity enforced badge if compositeIdentityEnforced is false', () => {
+          expect(
+            GfmAutoComplete.Members.templateFunction({
+              avatarTag: 'IMG',
+              username: 'my-user',
+              title: '',
+              icon: '',
+              availabilityStatus: '',
+              compositeIdentityEnforced: false,
+            }),
+          ).toBe('<li>IMG my-user <small></small> </li>');
+        });
+      });
+
       describe('nameOrUsernameStartsWith', () => {
         it.each`
           query             | result
@@ -1304,18 +1359,12 @@ describe('GfmAutoComplete', () => {
     const mockWorkItemId = 'gid://gitlab/WorkItem/1';
     const mockWorkItemFullPath = 'gitlab-test';
     const mockWorkItemIid = '1';
-    const originalGon = window.gon;
     const dataSources = {
       issues: `${TEST_HOST}/autocomplete_sources/issues`,
       members: `${TEST_HOST}/autocomplete_sources/members`,
     };
 
     beforeEach(() => {
-      window.gon = {
-        features: {
-          workItemViewForIssues: true,
-        },
-      };
       document.body.dataset.page = 'projects:issues:show';
       setHTMLFixture(`
         <section>
@@ -1334,7 +1383,6 @@ describe('GfmAutoComplete', () => {
     afterEach(() => {
       autocomplete.destroy();
       resetHTMLFixture();
-      window.gon = originalGon;
     });
 
     describe('unlink', () => {
