@@ -7,6 +7,7 @@ import {
   getScrollingElement,
   scrollToElement,
   smoothScrollTop,
+  getPanelElement,
 } from '~/lib/utils/scroll_utils';
 import { setHTMLFixture, resetHTMLFixture } from 'helpers/fixtures';
 
@@ -345,4 +346,18 @@ describe('scroll utils', () => {
       });
     });
   });
+
+  describe('getPanelElement', () => {
+    it('returns static panel element', () => {
+      expect(getPanelElement(findElem())).toBe(findStaticPanelInner());
+    });
+
+    it('returns dynamic panel element', () => {
+      expect(getPanelElement(findElemInDynamicPanel())).toBe(findDynamicPanelInner());
+    });
+
+    it('returns null without context', () => {
+      expect(getPanelElement()).toBeNull();
+    });
+  });
 });
