@@ -30,7 +30,6 @@ import PersistedSearch from '~/packages_and_registries/shared/components/persist
 import MetadataDatabaseBanner from '~/packages_and_registries/shared/components/container_registry_metadata_database_banner.vue';
 import { FILTERED_SEARCH_TERM } from '~/vue_shared/components/filtered_search_bar/constants';
 import TitleArea from '~/vue_shared/components/registry/title_area.vue';
-import { helpPagePath } from '~/helpers/help_page_helper';
 import { createAlert } from '~/alert';
 
 import { $toast } from 'jest/packages_and_registries/shared/mocks';
@@ -148,7 +147,6 @@ describe('List Page', () => {
     expect(findRegistryHeader().props()).toMatchObject({
       imagesCount: 2,
       metadataLoading: false,
-      helpPagePath: helpPagePath('user/packages/container_registry/_index'),
       hideExpirationPolicyData: false,
       showCleanupPolicyLink: false,
       expirationPolicy: {},
