@@ -11,7 +11,7 @@ import SignatureBadge from '~/commit/components/signature_badge.vue';
 import CiIcon from '~/vue_shared/components/ci_icon/ci_icon.vue';
 import eventHub from '~/repository/event_hub';
 import pathLastCommitQuery from 'shared_queries/repository/path_last_commit.query.graphql';
-import pipelineCiStatusUpdatedSubscription from '~/graphql_shared/subscriptions/pipeline_ci_status_updated.subscription.graphql';
+import pipelineStatusUpdatedSubscription from '~/repository/subscriptions/pipeline_status_updated.subscription.graphql';
 import { FORK_UPDATED_EVENT } from '~/repository/constants';
 import { mockPipelineStatusUpdatedResponse, createCommitData } from '../mock_data';
 
@@ -42,7 +42,7 @@ describe('Repository last commit component', () => {
 
     apolloProvider = createMockApollo([
       [pathLastCommitQuery, mockResolver],
-      [pipelineCiStatusUpdatedSubscription, pipelineSubscriptionHandler],
+      [pipelineStatusUpdatedSubscription, pipelineSubscriptionHandler],
     ]);
 
     wrapper = shallowMountExtended(LastCommit, {
@@ -177,6 +177,77 @@ describe('Repository last commit component', () => {
         pipelineId: 'gid://gitlab/Ci::Pipeline/167',
       });
     });
+
+    it('does not make redundant subscription calls for refetches', async () => {
+      createComponent();
+
+      await waitForPromises();
+
+      expect(subscriptionHandler).toHaveBeenCalledTimes(1);
+
+      wrapper.vm.refetchLastCommit();
+
+      await waitForPromises();
+
+      expect(subscriptionHandler).toHaveBeenCalledTimes(1);
+    });
+
+    it('does not resubscribe when pipeline ID remains the same during polling', async () => {
+      createComponent();
+
+      await waitForPromises();
+
+      expect(subscriptionHandler).toHaveBeenCalledTimes(1);
+
+      // Advance timers to trigger polling
+      jest.advanceTimersByTime(30000);
+      await waitForPromises();
+
+      expect(subscriptionHandler).toHaveBeenCalledTimes(1);
+    });
+
+    it('does resubscribe when pipeline ID changes during polling', async () => {
+      createComponent();
+
+      await waitForPromises();
+
+      expect(subscriptionHandler).toHaveBeenCalledTimes(1);
+      expect(subscriptionHandler).toHaveBeenCalledWith({
+        pipelineId: 'gid://gitlab/Ci::Pipeline/167',
+      });
+
+      // Simulate a poll/refetch that returns a different pipeline ID
+      const newCommitData = createCommitData({
+        pipelineEdges: [
+          {
+            __typename: 'PipelineEdge',
+            node: {
+              __typename: 'Pipeline',
+              id: 'gid://gitlab/Ci::Pipeline/200',
+              detailedStatus: {
+                __typename: 'DetailedStatus',
+                id: 'id',
+                detailsPath: 'https://test.com/pipeline',
+                icon: 'status_running',
+                text: 'failed',
+              },
+            },
+          },
+        ],
+      });
+
+      mockResolver.mockResolvedValueOnce(newCommitData);
+
+      // Advance timers to trigger polling
+      jest.advanceTimersByTime(30000);
+      await waitForPromises();
+
+      // Should have called the subscription handler again with the new ID
+      expect(subscriptionHandler).toHaveBeenCalledTimes(2);
+      expect(subscriptionHandler).toHaveBeenLastCalledWith({
+        pipelineId: 'gid://gitlab/Ci::Pipeline/200',
+      });
+    });
   });
 
   describe('polling', () => {
