@@ -1,5 +1,6 @@
 import { GlForm, GlFormFields, GlToggle, GlButton } from '@gitlab/ui';
 import { mount } from '@vue/test-utils';
+import { nextTick } from 'vue';
 import SettingsForm from '~/vscode_extension_marketplace/components/settings_form.vue';
 import { PRESETS } from '../mock_data';
 
@@ -126,6 +127,7 @@ describe('~/vscode_extension_marketplace/components/settings_form.vue', () => {
       });
 
       await findOpenVsxToggle().vm.$emit('change', false);
+      await nextTick();
 
       expect(findFormFields().props('values')).toEqual({
         useOpenVsx: false,
@@ -158,6 +160,7 @@ describe('~/vscode_extension_marketplace/components/settings_form.vue', () => {
         resourceUrlTemplate: 'xyz',
       });
       await findOpenVsxToggle().vm.$emit('change', true);
+      await nextTick();
 
       expect(findFormFields().props('values')).toEqual({
         useOpenVsx: true,
@@ -171,6 +174,7 @@ describe('~/vscode_extension_marketplace/components/settings_form.vue', () => {
       });
 
       await findOpenVsxToggle().vm.$emit('change', false);
+      await nextTick();
 
       expect(findFormFields().props('values')).toEqual({
         useOpenVsx: false,
