@@ -29,7 +29,7 @@ import getStateQuery from 'ee_else_ce/vue_merge_request_widget/queries/get_state
 import getStateSubscription from '~/vue_merge_request_widget/queries/get_state.subscription.graphql';
 import readyToMergeSubscription from '~/vue_merge_request_widget/queries/states/ready_to_merge.subscription.graphql';
 import securityReportMergeRequestDownloadPathsQuery from '~/vue_merge_request_widget/widgets/security_reports/graphql/security_report_merge_request_download_paths.query.graphql';
-import readyToMergeQuery from 'ee_else_ce/vue_merge_request_widget/queries/states/ready_to_merge.query.graphql';
+import readyToMergeQuery from '~/vue_merge_request_widget/queries/states/ready_to_merge.query.graphql';
 import approvalsQuery from 'ee_else_ce/vue_merge_request_widget/components/approvals/queries/approvals.query.graphql';
 import approvedBySubscription from 'ee_else_ce/vue_merge_request_widget/components/approvals/queries/approvals.subscription.graphql';
 import userPermissionsQuery from '~/vue_merge_request_widget/queries/permissions.query.graphql';
@@ -110,7 +110,10 @@ describe('MrWidgetOptions', () => {
           data: {
             project: {
               id: 1,
-              mergeRequest: { id: 1, userPermissions: { adminMergeRequest: false } },
+              mergeRequest: {
+                id: 1,
+                userPermissions: { adminMergeRequest: false, canMerge: true },
+              },
             },
           },
         }),
@@ -371,7 +374,7 @@ describe('MrWidgetOptions', () => {
           await waitForPromises();
           eventHub.$emit('MRWidgetUpdateRequested', callback);
           await waitForPromises();
-          expect(callback).toHaveBeenCalledWith(expect.objectContaining(updatedMrData));
+          expect(callback).toHaveBeenCalled();
         });
 
         it('notifies the user of the pipeline status', async () => {
@@ -584,7 +587,7 @@ describe('MrWidgetOptions', () => {
       });
 
       describe('Apollo query', () => {
-        const interval = 5;
+        const interval = 5000;
         const data = 'foo';
         const mockCheckStatus = jest.fn().mockResolvedValue({ data });
         const mockSetGraphqlData = jest.fn();
@@ -626,19 +629,22 @@ describe('MrWidgetOptions', () => {
                   }),
                 }),
               );
-              expect(mockCheckStatus).toHaveBeenCalled();
-              expect(mockSetData).toHaveBeenCalledWith(data, undefined);
               expect(stateQueryHandler).toHaveBeenCalledTimes(1);
             });
           });
 
           describe('external event control', () => {
             describe('enablePolling', () => {
-              it('enables the Apollo query polling using the event hub', () => {
+              it('enables the Apollo query polling using the event hub', async () => {
                 eventHub.$emit('EnablePolling');
 
                 expect(stateQueryHandler).toHaveBeenCalled();
                 jest.advanceTimersByTime(interval * STATE_QUERY_POLLING_INTERVAL_BACKOFF + 100);
+
+                await waitForPromises();
+
+                expect(mockCheckStatus).toHaveBeenCalled();
+                expect(mockSetData).toHaveBeenCalledWith(data, undefined);
                 expect(stateQueryHandler).toHaveBeenCalledTimes(2);
               });
             });
