@@ -253,6 +253,40 @@ describe('File row component', () => {
     });
   });
 
+  describe('rovingTabindex prop', () => {
+    it('sets tabindex to 0 by default', () => {
+      createComponent({
+        file: file('test.txt'),
+        level: 0,
+        rovingTabindex: false,
+      });
+
+      expect(findFileButton().attributes('tabindex')).toBe('0');
+    });
+
+    it('sets tabindex to -1 when rovingTabindex is true', () => {
+      createComponent({
+        file: file('test.txt'),
+        level: 0,
+        rovingTabindex: true,
+      });
+
+      expect(findFileButton().attributes('tabindex')).toBe('-1');
+    });
+  });
+
+  it('emits clickSubmodule with webUrl and does not call router.push for submodules', () => {
+    const push = jest.fn();
+    createComponent(
+      { file: { ...file('sub'), submodule: true, webUrl: 'https://ext.com' }, level: 0 },
+      { push, currentRoute: { path: '/different' } },
+    );
+    findFileButton().trigger('click');
+
+    expect(wrapper.emitted('clickSubmodule')[0][0]).toBe('https://ext.com');
+    expect(push).not.toHaveBeenCalled();
+  });
+
   describe('Tree toggle chevron button', () => {
     const findChevronButton = () => wrapper.findByTestId('tree-toggle-button');
     const folderPath = 'path/to/folder';
