@@ -1,41 +1,20 @@
-import { nextTick } from 'vue';
 import MockAdapter from 'axios-mock-adapter';
-import { GlAvatarLabeled, GlIcon, GlBadge } from '@gitlab/ui';
+import { GlAvatarLabeled, GlIcon, GlBadge, GlTooltip, GlAvatar } from '@gitlab/ui';
+import { stubComponent } from 'helpers/stub_component';
 import GroupsListItemPlanBadge from 'ee_component/vue_shared/components/groups_list/groups_list_item_plan_badge.vue';
 import axios from '~/lib/utils/axios_utils';
 import { mountExtended } from 'helpers/vue_test_utils_helper';
 import GroupsListItem from '~/vue_shared/components/groups_list/groups_list_item.vue';
-import { createMockDirective, getBinding } from 'helpers/vue_mock_directive';
-import waitForPromises from 'helpers/wait_for_promises';
-import GroupListItemDeleteModal from '~/vue_shared/components/groups_list/group_list_item_delete_modal.vue';
 import ListItemInactiveBadge from '~/vue_shared/components/resource_lists/list_item_inactive_badge.vue';
-import GroupListItemPreventDeleteModal from '~/vue_shared/components/groups_list/group_list_item_prevent_delete_modal.vue';
-import GroupListItemLeaveModal from '~/vue_shared/components/groups_list/group_list_item_leave_modal.vue';
 import GroupListItemActions from '~/vue_shared/components/groups_list/group_list_item_actions.vue';
-import {
-  VISIBILITY_TYPE_ICON,
-  VISIBILITY_LEVEL_PUBLIC_STRING,
-  GROUP_VISIBILITY_TYPE,
-} from '~/visibility_level/constants';
 import { ACCESS_LEVEL_LABELS, ACCESS_LEVEL_NO_ACCESS_INTEGER } from '~/access_level/constants';
 import TimeAgoTooltip from '~/vue_shared/components/time_ago_tooltip.vue';
 import {
   TIMESTAMP_TYPE_CREATED_AT,
   TIMESTAMP_TYPE_UPDATED_AT,
 } from '~/vue_shared/components/resource_lists/constants';
-import { renderDeleteSuccessToast } from '~/vue_shared/components/groups_list/utils';
-import { createAlert } from '~/alert';
 import { groups } from './mock_data';
 
-const MOCK_DELETE_PARAMS = {
-  testParam: true,
-};
-
-jest.mock('~/vue_shared/components/groups_list/utils', () => ({
-  ...jest.requireActual('~/vue_shared/components/groups_list/utils'),
-  renderDeleteSuccessToast: jest.fn(),
-  deleteParams: jest.fn(() => MOCK_DELETE_PARAMS),
-}));
 jest.mock('~/alert');
 
 describe('GroupsListItem', () => {
@@ -49,38 +28,30 @@ describe('GroupsListItem', () => {
   const createComponent = ({ propsData = {} } = {}) => {
     wrapper = mountExtended(GroupsListItem, {
       propsData: { ...defaultPropsData, ...propsData },
-      directives: {
-        GlTooltip: createMockDirective('gl-tooltip'),
-      },
       scopedSlots: {
         'children-toggle': '<div data-testid="children-toggle"></div>',
         children: '<div data-testid="children"></div>',
       },
+      stubs: { GlTooltip: stubComponent(GlTooltip) },
     });
   };
 
   const findAvatarLabeled = () => wrapper.findComponent(GlAvatarLabeled);
-  const findGroupDescription = () => wrapper.findByTestId('description');
+  const findGroupDescription = () => wrapper.findByTestId('description-html');
   const findVisibilityIcon = () => findAvatarLabeled().findComponent(GlIcon);
   const findGroupListItemActions = () => wrapper.findComponent(GroupListItemActions);
-  const findDeleteConfirmationModal = () => wrapper.findComponent(GroupListItemDeleteModal);
-  const findPreventDeleteModal = () => wrapper.findComponent(GroupListItemPreventDeleteModal);
-  const findLeaveModal = () => wrapper.findComponent(GroupListItemLeaveModal);
   const findAccessLevelBadge = () => wrapper.findByTestId('user-access-role');
   const findTimeAgoTooltip = () => wrapper.findComponent(TimeAgoTooltip);
-  const findSubgroupCount = () => wrapper.findByTestId('subgroups-count');
+  const findSubgroupsCount = () => wrapper.findByTestId('subgroups-count');
   const findProjectsCount = () => wrapper.findByTestId('projects-count');
   const findMembersCount = () => wrapper.findByTestId('members-count');
   const findStorageSize = () => wrapper.findByTestId('storage-size');
 
   const findInactiveBadge = () => wrapper.findComponent(ListItemInactiveBadge);
-
-  const deleteModalFireConfirmEvent = async () => {
-    findDeleteConfirmationModal().vm.$emit('confirm', {
-      preventDefault: jest.fn(),
-    });
-    await nextTick();
-  };
+  const findTooltipByTarget = (target) =>
+    wrapper
+      .findAllComponents(GlTooltip)
+      .wrappers.find((tooltip) => tooltip.props('target')() === target.element);
 
   beforeEach(() => {
     axiosMock = new MockAdapter(axios);
@@ -90,6 +61,36 @@ describe('GroupsListItem', () => {
     axiosMock.restore();
   });
 
+  describe('when includeMicrodata prop is true', () => {
+    beforeEach(() => {
+      createComponent({ propsData: { includeMicrodata: true } });
+    });
+
+    it('adds microdata attributes to list element', () => {
+      expect(wrapper.attributes()).toMatchObject({
+        itemprop: 'subOrganization',
+        itemtype: 'https://schema.org/Organization',
+        itemscope: expect.any(String),
+      });
+    });
+
+    it('adds microdata attributes to avatar', () => {
+      const avatarLabeled = findAvatarLabeled();
+
+      expect(avatarLabeled.props()).toMatchObject({
+        labelLinkAttrs: { itemprop: 'name' },
+      });
+
+      expect(avatarLabeled.findComponent(GlAvatar).attributes()).toMatchObject({
+        itemprop: 'logo',
+      });
+    });
+
+    it('adds microdata to description', () => {
+      expect(findGroupDescription().attributes()).toMatchObject({ itemprop: 'description' });
+    });
+  });
+
   it('renders group avatar', () => {
     createComponent();
 
@@ -98,41 +99,39 @@ describe('GroupsListItem', () => {
     expect(avatarLabeled.props()).toMatchObject({
       label: group.fullName,
       labelLink: group.relativeWebUrl,
-    });
-
-    expect(avatarLabeled.attributes()).toMatchObject({
-      'entity-id': group.id.toString(),
-      'entity-name': group.fullName,
+      entityId: group.id,
+      entityName: group.fullName,
       src: group.avatarUrl,
       shape: 'rect',
     });
   });
 
-  it('renders visibility icon with tooltip', () => {
+  it('renders subgroups count', () => {
     createComponent();
 
-    const icon = findAvatarLabeled().findComponent(GlIcon);
-    const tooltip = getBinding(icon.element, 'gl-tooltip');
-
-    expect(icon.props('name')).toBe(VISIBILITY_TYPE_ICON[VISIBILITY_LEVEL_PUBLIC_STRING]);
-    expect(tooltip.value).toBe(GROUP_VISIBILITY_TYPE[VISIBILITY_LEVEL_PUBLIC_STRING]);
-  });
-
-  it('renders subgroup count', () => {
-    createComponent();
-
-    expect(findSubgroupCount().props()).toMatchObject({
+    expect(findSubgroupsCount().props()).toMatchObject({
       tooltipText: 'Subgroups',
       iconName: 'subgroup',
       stat: group.descendantGroupsCount.toString(),
     });
   });
 
-  describe('when subgroup count is not available', () => {
+  describe('when subgroups count is hovered', () => {
+    beforeEach(() => {
+      createComponent();
+      findSubgroupsCount().vm.$emit('hover');
+    });
+
+    it('emits hover-stat', () => {
+      expect(wrapper.emitted('hover-stat')).toEqual([['subgroups-count']]);
+    });
+  });
+
+  describe('when subgroups count is not available', () => {
     it.each([undefined, null])('does not render subgroup count', (descendantGroupsCount) => {
       createComponent({ propsData: { group: { ...group, descendantGroupsCount } } });
 
-      expect(findSubgroupCount().exists()).toBe(false);
+      expect(findSubgroupsCount().exists()).toBe(false);
     });
   });
 
@@ -146,6 +145,17 @@ describe('GroupsListItem', () => {
     });
   });
 
+  describe('when projects count is hovered', () => {
+    beforeEach(() => {
+      createComponent();
+      findProjectsCount().vm.$emit('hover');
+    });
+
+    it('emits hover-stat', () => {
+      expect(wrapper.emitted('hover-stat')).toEqual([['projects-count']]);
+    });
+  });
+
   describe('when projects count is not available', () => {
     it.each([undefined, null])('does not render projects count', (projectsCount) => {
       createComponent({ propsData: { group: { ...group, projectsCount } } });
@@ -164,6 +174,17 @@ describe('GroupsListItem', () => {
     });
   });
 
+  describe('when members count is hovered', () => {
+    beforeEach(() => {
+      createComponent();
+      findMembersCount().vm.$emit('hover');
+    });
+
+    it('emits hover-stat', () => {
+      expect(wrapper.emitted('hover-stat')).toEqual([['members-count']]);
+    });
+  });
+
   describe('when members count is not available', () => {
     it.each([undefined, null])('does not render members count', (groupMembersCount) => {
       createComponent({ propsData: { group: { ...group, groupMembersCount } } });
@@ -172,6 +193,27 @@ describe('GroupsListItem', () => {
     });
   });
 
+  it('renders visibility icon with tooltip', () => {
+    createComponent();
+
+    const icon = findAvatarLabeled().findComponent(GlIcon);
+    const tooltip = findTooltipByTarget(icon);
+
+    expect(icon.props('name')).toBe('earth');
+    expect(tooltip.text()).toBe(
+      'Public - The group and any public projects can be viewed without any authentication.',
+    );
+  });
+
+  it('emits hover-visibility event when visibility icon tooltip is shown', () => {
+    createComponent();
+
+    const icon = findAvatarLabeled().findComponent(GlIcon);
+    findTooltipByTarget(icon).vm.$emit('shown');
+
+    expect(wrapper.emitted('hover-visibility')).toEqual([[group.visibility]]);
+  });
+
   describe('when visibility is not provided', () => {
     it('does not render visibility icon', () => {
       const { visibility, ...groupWithoutVisibility } = group;
@@ -325,167 +367,6 @@ describe('GroupsListItem', () => {
         expect(wrapper.emitted('refetch')).toEqual([[]]);
       });
     });
-
-    describe('when list item actions emits leave', () => {
-      it('shows leave modal', async () => {
-        findGroupListItemActions().vm.$emit('leave');
-        await nextTick();
-
-        expect(findLeaveModal().props('visible')).toBe(true);
-      });
-
-      describe('when leave modal emits visibility change', () => {
-        it("updates the modal's visibility prop", async () => {
-          findLeaveModal().vm.$emit('change', false);
-
-          await nextTick();
-
-          expect(findLeaveModal().props('visible')).toBe(false);
-        });
-      });
-
-      describe('when leave modal emits success event', () => {
-        it('emits refetch event', () => {
-          findLeaveModal().vm.$emit('success');
-
-          expect(wrapper.emitted('refetch')).toEqual([[]]);
-        });
-      });
-    });
-
-    describe('when list item actions emits delete', () => {
-      describe('when group is linked to a subscription', () => {
-        const groupLinkedToSubscription = {
-          ...group,
-          isLinkedToSubscription: true,
-        };
-
-        beforeEach(async () => {
-          createComponent({
-            propsData: {
-              group: groupLinkedToSubscription,
-            },
-          });
-
-          findGroupListItemActions().vm.$emit('delete');
-          await nextTick();
-        });
-
-        it('displays prevent delete modal', () => {
-          expect(findPreventDeleteModal().props()).toMatchObject({
-            visible: true,
-          });
-        });
-
-        describe('when change is fired', () => {
-          beforeEach(() => {
-            findPreventDeleteModal().vm.$emit('change', false);
-          });
-
-          it('updates visibility prop', () => {
-            expect(findPreventDeleteModal().props('visible')).toBe(false);
-          });
-        });
-      });
-
-      describe('when group can be deleted', () => {
-        beforeEach(async () => {
-          createComponent({
-            propsData: {
-              group,
-            },
-          });
-
-          findGroupListItemActions().vm.$emit('delete');
-          await nextTick();
-        });
-
-        it('displays confirmation modal with correct props', () => {
-          expect(findDeleteConfirmationModal().props()).toMatchObject({
-            visible: true,
-            phrase: group.fullName,
-            confirmLoading: false,
-          });
-        });
-
-        describe('when deletion is confirmed', () => {
-          describe('when API call is successful', () => {
-            it('calls DELETE on group path, properly sets loading state, and emits refetch event', async () => {
-              axiosMock.onDelete(group.relativeWebUrl).reply(200);
-
-              await deleteModalFireConfirmEvent();
-              expect(findDeleteConfirmationModal().props('confirmLoading')).toBe(true);
-
-              await waitForPromises();
-
-              expect(axiosMock.history.delete[0].params).toEqual(MOCK_DELETE_PARAMS);
-              expect(findDeleteConfirmationModal().props('confirmLoading')).toBe(false);
-              expect(wrapper.emitted('refetch')).toEqual([[]]);
-              expect(renderDeleteSuccessToast).toHaveBeenCalledWith(group);
-              expect(createAlert).not.toHaveBeenCalled();
-            });
-          });
-
-          describe('when API call is not successful', () => {
-            it('calls DELETE on group path, properly sets loading state, and shows error alert', async () => {
-              axiosMock.onDelete(group.relativeWebUrl).networkError();
-
-              await deleteModalFireConfirmEvent();
-              expect(findDeleteConfirmationModal().props('confirmLoading')).toBe(true);
-
-              await waitForPromises();
-
-              expect(axiosMock.history.delete[0].params).toEqual(MOCK_DELETE_PARAMS);
-              expect(findDeleteConfirmationModal().props('confirmLoading')).toBe(false);
-              expect(wrapper.emitted('refetch')).toBeUndefined();
-              expect(createAlert).toHaveBeenCalledWith({
-                message:
-                  'An error occurred deleting the group. Please refresh the page to try again.',
-                error: new Error('Network Error'),
-                captureError: true,
-              });
-              expect(renderDeleteSuccessToast).not.toHaveBeenCalled();
-            });
-          });
-        });
-
-        describe('when change is fired', () => {
-          beforeEach(() => {
-            findDeleteConfirmationModal().vm.$emit('change', false);
-          });
-
-          it('updates visibility prop', () => {
-            expect(findDeleteConfirmationModal().props('visible')).toBe(false);
-          });
-        });
-      });
-
-      describe('when group can be deleted immediately', () => {
-        beforeEach(async () => {
-          createComponent({
-            propsData: {
-              group: {
-                ...group,
-                markedForDeletion: true,
-                isSelfDeletionInProgress: true,
-                isSelfDeletionScheduled: false,
-              },
-            },
-          });
-
-          findGroupListItemActions().vm.$emit('delete');
-          await nextTick();
-        });
-
-        it('displays confirmation modal with correct props', () => {
-          expect(findDeleteConfirmationModal().props()).toMatchObject({
-            visible: true,
-            phrase: group.fullName,
-            confirmLoading: false,
-          });
-        });
-      });
-    });
   });
 
   describe('when group does not have actions', () => {
@@ -503,10 +384,6 @@ describe('GroupsListItem', () => {
     it('does not render list item actions', () => {
       expect(findGroupListItemActions().exists()).toBe(false);
     });
-
-    it('does not display confirmation modal', () => {
-      expect(findDeleteConfirmationModal().exists()).toBe(false);
-    });
   });
 
   describe.each`
