@@ -112,6 +112,7 @@ describe('WikiForm', () => {
           csrfToken: '',
           pagePersisted: false,
           drawioUrl: null,
+          glFeatures: { wikiImmersiveEditor: false },
           ...provide,
         },
         stubs: {
@@ -155,6 +156,7 @@ describe('WikiForm', () => {
         renderMarkdownPath: pageInfoPersisted.markdownPreviewPath,
         uploadsPath: pageInfoPersisted.uploadsPath,
         autofocus: pageInfoPersisted.persisted,
+        immersive: false,
       }),
     );
 
@@ -662,4 +664,19 @@ describe('WikiForm', () => {
       });
     });
   });
+
+  describe('immersive mode', () => {
+    beforeEach(() => {
+      createWrapper({
+        mountFn: shallowMount,
+        provide: {
+          glFeatures: { wikiImmersiveEditor: true },
+        },
+      });
+    });
+
+    it('enables immersive mode on markdown editor', () => {
+      expect(findMarkdownEditor().props().immersive).toBe(true);
+    });
+  });
 });
