@@ -14,7 +14,6 @@ describe('WorkItemBreadcrumb', () => {
     listPath = '/epics',
     isGroup = true,
     workItemPlanningView = false,
-    workItemViewForIssues = false,
     props = {},
   } = {}) => {
     wrapper = shallowMount(WorkItemBreadcrumb, {
@@ -22,7 +21,6 @@ describe('WorkItemBreadcrumb', () => {
         workItemType,
         glFeatures: {
           workItemPlanningView,
-          workItemViewForIssues,
         },
         listPath,
         isGroup,
@@ -44,6 +42,7 @@ describe('WorkItemBreadcrumb', () => {
           to: {
             name: 'workItemList',
             query: undefined,
+            params: { type: 'work_items' },
           },
         },
       ]);
@@ -58,6 +57,7 @@ describe('WorkItemBreadcrumb', () => {
           to: {
             name: 'workItemList',
             query: undefined,
+            params: { type: 'issues' },
           },
         },
       ]);
@@ -72,6 +72,7 @@ describe('WorkItemBreadcrumb', () => {
           to: {
             name: 'workItemList',
             query: undefined,
+            params: { type: 'epics' },
           },
         },
       ]);
@@ -80,48 +81,52 @@ describe('WorkItemBreadcrumb', () => {
 
   describe('when the workspace is a project', () => {
     describe('when in issues mode', () => {
-      it('renders root `Issues` breadcrumb with href on work items list page', () => {
+      it('renders root breadcrumb with router link if on work item project issues list', () => {
         createComponent({ isGroup: false, listPath: '/issues' });
 
-        expect(findBreadcrumb().props('items')).toEqual([
-          {
-            text: 'Issues',
-            href: '/issues',
-          },
-        ]);
-      });
-
-      it('renders root breadcrumb with router link if user turned work item view on and is on work item project issues list', () => {
-        createComponent({
-          isGroup: false,
-          listPath: '/issues',
-          workItemViewForIssues: true,
-        });
-
         expect(findBreadcrumb().props('items')).toEqual([
           {
             text: 'Issues',
             to: {
               name: 'workItemList',
               query: undefined,
+              params: { type: 'issues' },
             },
           },
         ]);
       });
     });
+
+    describe('when task is on work_items path with feature flag off', () => {
+      it('renders root `Issues` breadcrumb with href to respect feature flag state', () => {
+        createComponent({
+          isGroup: false,
+          listPath: '/issues',
+          workItemViewForIssues: true,
+          $route: { path: '/work_items/123' },
+        });
+
+        expect(findBreadcrumb().props('items')).toEqual([
+          {
+            text: 'Issues',
+            href: '/issues',
+          },
+        ]);
+      });
+    });
   });
 
   it('renders `New` breadcrumb on new work item page', () => {
     createComponent({ $route: { name: 'new' } });
 
     expect(findBreadcrumb().props('items')).toEqual(
-      expect.arrayContaining([{ text: 'New', to: 'new' }]),
+      expect.arrayContaining([{ text: 'New', to: { name: 'new', params: { type: 'issues' } } }]),
     );
   });
 
   it('combines static and dynamic breadcrumbs', () => {
     createComponent({
-      $route: { name: 'workItem', params: { iid: '1' }, path: '/1' },
+      $route: { name: 'workItem', params: { iid: '1', type: 'issues' }, path: '/1' },
       props: {
         staticBreadcrumbs: [{ text: 'Static', href: '/static' }],
       },
@@ -129,16 +134,23 @@ describe('WorkItemBreadcrumb', () => {
 
     expect(findBreadcrumb().props('items')).toEqual([
       { text: 'Static', href: '/static' },
-      { text: 'Issues', to: { name: 'workItemList', query: undefined } },
-      { text: '#1', to: '/1' },
+      {
+        text: 'Issues',
+        to: { name: 'workItemList', query: undefined, params: { type: 'issues' } },
+      },
+      { text: '#1', to: { name: 'workItem', params: { type: 'issues', iid: '1' } } },
     ]);
   });
 
   it('renders work item iid breadcrumb on work item detail page', () => {
-    createComponent({ $route: { name: 'workItem', params: { iid: '1' }, path: '/1' } });
+    createComponent({
+      $route: { name: 'workItem', params: { iid: '1', type: 'issues' }, path: '/1' },
+    });
 
     expect(findBreadcrumb().props('items')).toEqual(
-      expect.arrayContaining([{ text: '#1', to: '/1' }]),
+      expect.arrayContaining([
+        { text: '#1', to: { name: 'workItem', params: { type: 'issues', iid: '1' } } },
+      ]),
     );
   });
 });
