@@ -163,7 +163,7 @@ describe('work items graphql resolvers', () => {
             workItemType: {
               id: 'gid://gitlab/WorkItems::Type/8',
               name: 'Epic',
-              iconName: 'issue-type-epic',
+              iconName: 'work-item-epic',
               __typename: 'WorkItemType',
             },
             __typename: 'WorkItem',
@@ -186,7 +186,7 @@ describe('work items graphql resolvers', () => {
             workItemType: {
               id: 'gid://gitlab/WorkItems::Type/8',
               name: 'Epic',
-              iconName: 'issue-type-epic',
+              iconName: 'work-item-epic',
               __typename: 'WorkItemType',
             },
             __typename: 'WorkItem',
