@@ -512,22 +512,6 @@ RSpec.describe ApplicationHelper do
     end
   end
 
-  describe '#project_studio_available?' do
-    let(:user) { build(:user) }
-
-    before do
-      allow(helper).to receive_messages(current_user: user, cookies: { studio: 'true' })
-    end
-
-    it 'calls ProjectStudio#available?' do
-      expect_next_instance_of(Users::ProjectStudio, user) do |studio|
-        expect(studio).to receive(:available?)
-      end
-
-      helper.project_studio_available?
-    end
-  end
-
   describe '#project_studio_enabled?' do
     let(:user) { build(:user) }
 
@@ -553,8 +537,7 @@ RSpec.describe ApplicationHelper do
             page_type_id: nil,
             group: nil,
             group_full_path: nil,
-            project_studio_available: 'false',
-            project_studio_enabled: 'false'
+            project_studio_enabled: 'true'
           }
         )
       end
@@ -571,8 +554,7 @@ RSpec.describe ApplicationHelper do
               page_type_id: nil,
               group: group.path,
               group_full_path: group.full_path,
-              project_studio_available: 'false',
-              project_studio_enabled: 'false'
+              project_studio_enabled: 'true'
             }
           )
         end
@@ -599,8 +581,7 @@ RSpec.describe ApplicationHelper do
             project: project.path,
             project_full_path: project.full_path,
             namespace_id: project.namespace.id,
-            project_studio_available: 'false',
-            project_studio_enabled: 'false'
+            project_studio_enabled: 'true'
           }
         )
       end
@@ -619,8 +600,7 @@ RSpec.describe ApplicationHelper do
               project: project.path,
               project_full_path: project.full_path,
               namespace_id: project.namespace.id,
-              project_studio_available: 'false',
-              project_studio_enabled: 'false'
+              project_studio_enabled: 'true'
             }
           )
         end
@@ -647,8 +627,7 @@ RSpec.describe ApplicationHelper do
                 project: issue.project.path,
                 project_full_path: project.full_path,
                 namespace_id: issue.project.namespace.id,
-                project_studio_available: 'false',
-                project_studio_enabled: 'false'
+                project_studio_enabled: 'true'
               }
             )
           end
@@ -802,14 +781,14 @@ RSpec.describe ApplicationHelper do
             allow(helper).to receive(:current_user).and_return(user)
           end
 
-          it { is_expected.not_to include('with-header') }
+          it { is_expected.to include('with-header') }
 
-          context 'when `project studio` feature is enabled' do
+          context 'when `project studio` feature is disabled' do
             before do
-              allow(helper).to receive(:project_studio_enabled?).and_return(true)
+              allow(helper).to receive(:project_studio_enabled?).and_return(false)
             end
 
-            it { is_expected.to include('with-header') }
+            it { is_expected.not_to include('with-header') }
           end
         end
 
@@ -880,17 +859,17 @@ RSpec.describe ApplicationHelper do
   end
 
   describe '#body_scroll_classes' do
-    it 'fixes body scroll by default' do
-      expect(helper.body_scroll_classes).to eq('body-fixed-scrollbar')
+    it 'does not fix body scroll' do
+      expect(helper.body_scroll_classes).to eq('')
     end
 
-    context 'when `project studio` feature is enabled' do
+    context 'when `project studio` feature is disabled' do
       before do
-        allow(helper).to receive(:project_studio_enabled?).and_return(true)
+        allow(helper).to receive(:project_studio_enabled?).and_return(false)
       end
 
-      it 'does not fix body scroll' do
-        expect(helper.body_scroll_classes).to eq('')
+      it 'fixes body scroll by default' do
+        expect(helper.body_scroll_classes).to eq('body-fixed-scrollbar')
       end
     end
   end
