@@ -51,7 +51,9 @@ RSpec.describe Ci::PipelinesHelper, feature_category: :continuous_integration do
         :full_path,
         :visibility_pipeline_id_type,
         :show_jenkins_ci_prompt,
-        :pipelines_analytics_path
+        :pipelines_analytics_path,
+        :uses_external_config,
+        :empty_state_illustration_path
       )
     end
   end
@@ -160,4 +162,29 @@ RSpec.describe Ci::PipelinesHelper, feature_category: :continuous_integration do
       end
     end
   end
+
+  describe '#uses_external_config?' do
+    using RSpec::Parameterized::TableSyntax
+
+    subject(:uses_external_config) { helper.uses_external_config?(project) }
+
+    let(:project_config) { instance_double(Gitlab::Ci::ProjectConfig, external?: is_external) }
+
+    before do
+      allow(Gitlab::Ci::ProjectConfig).to receive(:new)
+                                            .with(project: project, sha: nil)
+                                            .and_return(project_config)
+    end
+
+    where(:is_external, :expected_result) do
+      true | true
+      false | false
+    end
+
+    with_them do
+      it 'returns the expected result' do
+        expect(uses_external_config).to be expected_result
+      end
+    end
+  end
 end
