@@ -601,7 +601,7 @@ RSpec.describe GroupsHelper, feature_category: :groups_and_projects do
 
     context 'when ancestor is archived' do
       before do
-        ancestor.archive
+        ancestor.namespace_settings.update!(archived: true)
       end
 
       it 'returns correct data' do
@@ -677,110 +677,6 @@ RSpec.describe GroupsHelper, feature_category: :groups_and_projects do
     end
   end
 
-  describe '#access_level_roles_user_can_assign' do
-    subject { helper.access_level_roles_user_can_assign(group, group.access_level_roles) }
-
-    let_it_be(:group) { create(:group) }
-    let_it_be_with_reload(:user) { create(:user) }
-
-    context 'when user is provided' do
-      before do
-        allow(helper).to receive(:current_user).and_return(user)
-      end
-
-      context 'when a user is a group member' do
-        before do
-          group.add_developer(user)
-        end
-
-        it 'returns only the roles the provided user can assign' do
-          expect(subject).to eq(
-            {
-              'Guest' => 10,
-              'Reporter' => 20,
-              'Developer' => 30
-            }
-          )
-        end
-      end
-
-      context 'when a user is an admin', :enable_admin_mode do
-        before do
-          user.update!(admin: true)
-        end
-
-        it 'returns all roles' do
-          expect(subject).to eq(
-            {
-              'Guest' => 10,
-              'Planner' => 15,
-              'Reporter' => 20,
-              'Developer' => 30,
-              'Maintainer' => 40,
-              'Owner' => 50
-            }
-          )
-        end
-      end
-
-      context 'when a user is not a group member' do
-        it 'returns the empty array' do
-          expect(subject).to be_empty
-        end
-      end
-
-      context 'when a user has different access for different groups in the hierarchy' do
-        let_it_be(:grand_parent) { create(:group) }
-        let_it_be(:parent) { create(:group, parent: grand_parent) }
-        let_it_be(:child) { create(:group, parent: parent) }
-        let_it_be(:grand_child) { create(:group, parent: child) }
-
-        before_all do
-          parent.add_developer(user)
-          child.add_maintainer(user)
-          grand_child.add_owner(user)
-        end
-
-        it 'returns the access levels that are peers or lower' do
-          expect(helper.access_level_roles_user_can_assign(grand_parent, group.access_level_roles)).to be_empty
-          expect(helper.access_level_roles_user_can_assign(parent, group.access_level_roles)).to eq({
-            'Guest' => ::Gitlab::Access::GUEST,
-            'Reporter' => ::Gitlab::Access::REPORTER,
-            'Developer' => ::Gitlab::Access::DEVELOPER
-          })
-          expect(helper.access_level_roles_user_can_assign(child, group.access_level_roles)).to eq({
-            'Guest' => ::Gitlab::Access::GUEST,
-            'Reporter' => ::Gitlab::Access::REPORTER,
-            'Developer' => ::Gitlab::Access::DEVELOPER,
-            'Maintainer' => ::Gitlab::Access::MAINTAINER
-          })
-          expect(helper.access_level_roles_user_can_assign(grand_child, group.access_level_roles)).to eq(::Gitlab::Access.options_with_owner)
-        end
-      end
-
-      context 'when a group is linked to another' do
-        let_it_be(:other_group) { create(:group) }
-        let_it_be(:group_link) { create(:group_group_link, shared_group: group, shared_with_group: other_group, group_access: Gitlab::Access::MAINTAINER) }
-
-        before_all do
-          other_group.add_owner(user)
-        end
-
-        it { is_expected.to eq({ "Developer" => 30, "Guest" => 10, "Maintainer" => 40, "Reporter" => 20 }) }
-      end
-
-      context 'when user is not provided' do
-        before do
-          allow(helper).to receive(:current_user).and_return(nil)
-        end
-
-        it 'returns the empty array' do
-          expect(subject).to be_empty
-        end
-      end
-    end
-  end
-
   describe '#show_prevent_inviting_groups_outside_hierarchy_setting?' do
     let_it_be(:group) { create(:group) }
 
