@@ -978,6 +978,26 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
 
       expect(subject).to include(canAddCatalogResource: false)
     end
+
+    context 'when work_items_consolidated_list is disabled' do
+      before do
+        stub_feature_flags(work_item_planning_view: false)
+      end
+
+      it 'includes issuesHelpPath pointing to the issues documentation' do
+        expect(subject).to include(issuesHelpPath: '/help/user/project/issues/_index.md')
+      end
+    end
+
+    context 'when work_items_consolidated_list is enabled' do
+      before do
+        stub_feature_flags(work_item_planning_view: true)
+      end
+
+      it 'includes issuesHelpPath pointing to work items documentation' do
+        expect(subject).to include(issuesHelpPath: '/help/user/work_items/_index.md')
+      end
+    end
   end
 
   describe '#project_classes' do
@@ -1243,7 +1263,6 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
           admin_path: (admin_project_path(project) if has_admin_path),
           can_read_project: can_read_project.to_s,
           cicd_catalog_path: nil,
-          is_project_archived: "false",
           project_avatar: nil,
           is_project_empty: is_empty_repo.to_s,
           project_id: project.id,
@@ -2055,7 +2074,7 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
 
     context 'when ancestor is archived' do
       before do
-        ancestor.archive
+        ancestor.namespace_settings.update!(archived: true)
       end
 
       it 'returns correct data' do
@@ -2086,7 +2105,7 @@ RSpec.describe ProjectsHelper, feature_category: :source_code_management do
 
     context 'when ancestor is archived' do
       before do
-        group.archive
+        group.namespace_settings.update!(archived: true)
       end
 
       it { is_expected.to be(true) }
