@@ -316,7 +316,7 @@ RSpec.describe Banzai::Filter::References::MilestoneReferenceFilter, feature_cat
 
   shared_examples 'references with HTML entities' do
     before do
-      milestone.update!(title: '&lt;html&gt;')
+      milestone.update!(title: '<html>')
     end
 
     it 'links to a valid reference' do
@@ -340,7 +340,7 @@ RSpec.describe Banzai::Filter::References::MilestoneReferenceFilter, feature_cat
       result = reference_filter("See #{absolute_reference}")
 
       expect(result.css('a').first.attr('href')).to eq(urls.milestone_url(milestone))
-      expect(result.css('a').first.attr('data-original')).to eq absolute_reference
+      expect(result.css('a').first.attr('data-original')).to eq_html(absolute_reference)
       expect(result.content).to eq "See %#{milestone.title}"
     end
   end
@@ -627,4 +627,22 @@ RSpec.describe Banzai::Filter::References::MilestoneReferenceFilter, feature_cat
       end.not_to exceed_all_query_limit(control_count)
     end
   end
+
+  it_behaves_like 'a reference which does not unescape its content in data-original' do
+    let(:context)                 { { project: project } }
+    let(:milestone_title)         { "x<script>alert('xss');</script>" }
+    let(:milestone_title_escaped) { "x&lt;script&gt;alert('xss');&lt;/script&gt;" }
+    let(:resource)                { create(:milestone, title: milestone_title, project: project) }
+    let(:reference)               { %(#{resource.class.reference_prefix}"#{milestone_title_escaped}") }
+
+    let(:expected_resource_title)   { milestone_title }
+    let(:expected_href)             { urls.milestone_url(resource) }
+    let(:expected_replacement_text) { %(#{resource.class.reference_prefix}#{milestone_title}) }
+  end
+
+  it_behaves_like 'ReferenceFilter#references_in' do
+    let(:milestone) { create(:milestone, project: project) }
+    let(:reference) { milestone.to_reference }
+    let(:filter_instance) { described_class.new(nil, { project: }) }
+  end
 end
