@@ -15,9 +15,15 @@ RSpec.describe ::Authz::GranularScope, feature_category: :permissions do
       let_it_be(:organization) { create(:organization) }
       let_it_be(:namespace1) { create(:namespace, organization: organization) }
       let_it_be(:namespace2) { create(:namespace, organization: organization) }
-      let_it_be(:scope_with_namespace1) { create(:granular_scope, namespace: namespace1, organization: organization) }
-      let_it_be(:scope_with_namespace2) { create(:granular_scope, namespace: namespace2, organization: organization) }
-      let_it_be(:scope_without_namespace) { create(:granular_scope, :standalone, organization: organization) }
+      let_it_be(:scope_with_namespace1) do
+        create(:granular_scope, :selected_memberships, namespace: namespace1, organization: organization)
+      end
+
+      let_it_be(:scope_with_namespace2) do
+        create(:granular_scope, :selected_memberships, namespace: namespace2, organization: organization)
+      end
+
+      let_it_be(:scope_without_namespace) { create(:granular_scope, :user, organization: organization) }
 
       it 'returns scopes for the given namespace' do
         expect(described_class.with_namespace(namespace1.id)).to contain_exactly(scope_with_namespace1)
@@ -39,13 +45,17 @@ RSpec.describe ::Authz::GranularScope, feature_category: :permissions do
   end
 
   describe 'validations' do
+    # Actual permission with existing YAML definition file in
+    # config/authz/permission_groups/assignable_permissions/
+    let(:permission) { :create_member_role }
+
     describe 'permissions' do
       where(:permissions, :valid) do
-        nil              | false
-        'create_issue'   | false
-        []               | false
-        %w[xxx]          | false
-        %w[create_issue] | true
+        nil                | false
+        ref(:permission)   | false
+        []                 | false
+        %w[xxx]            | false
+        [ref(:permission)] | true
       end
 
       with_them do
@@ -87,27 +97,45 @@ RSpec.describe ::Authz::GranularScope, feature_category: :permissions do
   describe '.permitted_for_boundary?' do
     let_it_be(:project) { create(:project) }
     let_it_be(:boundary) { Authz::Boundary.for(project) }
-    let_it_be(:token_permissions) { ::Authz::Permission.all.keys.take(2) }
-    let_it_be(:required_permissions) { token_permissions.first }
 
     subject { described_class.permitted_for_boundary?(boundary, required_permissions) }
 
-    context 'when a scope exists for a boundary' do
-      before do
-        create(:granular_scope, namespace: boundary.namespace, permissions: token_permissions)
+    shared_examples 'checks for permission on boundary' do
+      context 'when a scope exists for a boundary' do
+        before do
+          create(:granular_scope, :selected_memberships, namespace: boundary.namespace,
+            permissions: token_permissions)
+        end
+
+        it { is_expected.to be true }
+
+        context 'when the scope does not include the required permissions' do
+          let_it_be(:required_permissions) { :not_allowed_permission }
+
+          it { is_expected.to be false }
+        end
       end
 
-      it { is_expected.to be true }
-
-      context 'when the scope does not include the required permissions' do
-        let_it_be(:required_permissions) { :not_allowed_permission }
-
+      context 'when a scope does not exist for a boundary' do
         it { is_expected.to be false }
       end
     end
 
-    context 'when a scope does not exist for a boundary' do
-      it { is_expected.to be false }
+    context 'with individual permissions' do
+      let_it_be(:token_permissions) { %i[create_member_role delete_member_role] }
+      let_it_be(:required_permissions) { :delete_member_role }
+
+      it_behaves_like 'checks for permission on boundary'
+    end
+
+    context 'with grouped permissions' do
+      let_it_be(:token_permissions) do
+        %i[edit_wiki] # expands to :update_wiki and :upload_wiki_attachment raw permissions
+      end
+
+      let_it_be(:required_permissions) { :upload_wiki_attachment }
+
+      it_behaves_like 'checks for permission on boundary'
     end
   end
 
@@ -127,15 +155,18 @@ RSpec.describe ::Authz::GranularScope, feature_category: :permissions do
     let_it_be(:other_namespace_boundary) { Authz::Boundary.for(create(:project)) }
 
     before do
-      allow(::Authz::Permission).to receive(:all).and_return((:a..:i).index_with(nil))
+      allow(::Authz::PermissionGroups::Assignable).to receive(:all).and_return((:a..:i).index_with { |p|
+        instance_double(::Authz::PermissionGroups::Assignable, permissions: [p])
+      })
 
-      create(:granular_scope, namespace: nil_boundary.namespace, permissions: [:a])
-      create(:granular_scope, namespace: rootgroup_boundary.namespace, permissions: [:b, :c])
-      create(:granular_scope, namespace: subgroup_boundary.namespace, permissions: [:c, :d])
-      create(:granular_scope, namespace: project_boundary.namespace, permissions: [:d, :e])
-      create(:granular_scope, namespace: user_boundary.namespace, permissions: [:f, :g])
-      create(:granular_scope, namespace: personal_project_boundary.namespace, permissions: [:g, :h])
-      create(:granular_scope, :all_membership_namespaces, permissions: [:i])
+      create(:granular_scope, :instance, permissions: [:a])
+      create(:granular_scope, :selected_memberships, namespace: rootgroup_boundary.namespace, permissions: [:b, :c])
+      create(:granular_scope, :selected_memberships, namespace: subgroup_boundary.namespace, permissions: [:c, :d])
+      create(:granular_scope, :selected_memberships, namespace: project_boundary.namespace, permissions: [:d, :e])
+      create(:granular_scope, :personal_projects, namespace: user_boundary.namespace, permissions: [:f, :g])
+      create(:granular_scope, :selected_memberships, namespace: personal_project_boundary.namespace,
+        permissions: [:g, :h])
+      create(:granular_scope, :all_memberships, permissions: [:i])
     end
 
     where(:boundary, :expected_result) do
@@ -148,10 +179,22 @@ RSpec.describe ::Authz::GranularScope, feature_category: :permissions do
       ref(:other_namespace_boundary)  | [:i]
     end
 
-    subject { described_class.token_permissions(boundary) }
+    subject(:permissions) { described_class.token_permissions(boundary) }
 
     with_them do
       it { is_expected.to match_array(expected_result) }
     end
+
+    describe 'persisted but undefined assignable permission group' do
+      let(:boundary) { nil_boundary }
+
+      before do
+        build(:granular_scope, :instance, permissions: [:non_existing]).save!(validate: false)
+      end
+
+      it 'is ignored' do
+        expect(permissions).to match_array([:a, :i])
+      end
+    end
   end
 end
