@@ -557,14 +557,6 @@ EOS
       let(:commit) { project.commit('video') }
 
       it { expect(commit.cherry_pick_message(user)).to include("\n\n(cherry picked from commit 88790590ed1337ab189bccaa355f068481c90bec)") }
-
-      context 'when "more_commits_from_gitaly" feature flag is disabled' do
-        before do
-          stub_feature_flags(more_commits_from_gitaly: false)
-        end
-
-        it { expect(commit.cherry_pick_message(user)).to include("\n\n(cherry picked from commit 88790590ed1337ab189bccaa355f068481c90bec)") }
-      end
     end
 
     context 'of a merge commit' do
