@@ -4,7 +4,8 @@ require "spec_helper"
 
 RSpec.describe SystemHook, feature_category: :webhooks do
   it_behaves_like 'a hook that does not get automatically disabled on failure' do
-    let(:hook) { build(:system_hook) }
+    let_it_be(:organization) { create(:organization) }
+    let_it_be(:hook) { create(:system_hook, organization: organization) }
     let(:hook_factory) { :system_hook }
     let(:default_factory_arguments) { {} }
 
@@ -31,6 +32,7 @@ RSpec.describe SystemHook, feature_category: :webhooks do
       let(:url) { 'http://localhost:9000' }
 
       it { is_expected.not_to allow_value(url).for(:url) }
+      it { is_expected.to validate_presence_of(:organization_id) }
 
       it 'is valid if application settings allow local requests from system hooks' do
         settings = ApplicationSetting.new(allow_local_requests_from_system_hooks: true)
@@ -43,6 +45,7 @@ RSpec.describe SystemHook, feature_category: :webhooks do
 
   describe 'associations' do
     it { is_expected.to have_many(:web_hook_logs) }
+    it { is_expected.to belong_to :organization }
   end
 
   describe '#destroy' do
