@@ -80,7 +80,7 @@ RSpec.describe OauthAccessToken, feature_category: :system_access do
       end
 
       it 'finds token stored with PBKDF2 strategy' do
-        pbkdf2_hash = Gitlab::DoorkeeperSecretStoring::Token::Pbkdf2Sha512.transform_secret(plain_secret)
+        pbkdf2_hash = Gitlab::DoorkeeperSecretStoring::Pbkdf2Sha512.transform_secret(plain_secret)
         pbkdf2_token.update_column(:token, pbkdf2_hash)
 
         result = described_class.find_by_fallback_token(:token, plain_secret)
@@ -90,8 +90,19 @@ RSpec.describe OauthAccessToken, feature_category: :system_access do
           plain_secret)
       end
 
-      it 'finds token stored with Plain strategy when PBKDF2 fails' do
-        # Create a different plain secret that won't match any PBKDF2 token
+      context "with FIPS mode", :fips_mode do
+        it 'does not find token stored with PBKDF2 strategy' do
+          pbkdf2_hash = Gitlab::DoorkeeperSecretStoring::Pbkdf2Sha512.transform_secret(plain_secret)
+          pbkdf2_token.update_column(:token, pbkdf2_hash)
+
+          result = described_class.find_by_fallback_token(:token, plain_secret)
+
+          expect(result).not_to eq(pbkdf2_token)
+        end
+      end
+
+      it 'finds token stored with Plain strategy when SHA512 fails' do
+        # Create a different plain secret that won't match any SHA512 token
         different_secret = 'different_plain_token_xyz'
         plain_token.update_column(:token, different_secret)
 
@@ -102,22 +113,10 @@ RSpec.describe OauthAccessToken, feature_category: :system_access do
           different_secret)
       end
 
-      it 'finds token stored with SHA512 strategy when PBKDF2 fails' do
-        plaintext_token_value = "123456"
-        value = Gitlab::DoorkeeperSecretStoring::Token::Sha512Hash.transform_secret(plaintext_token_value)
-        sha512_token.update_column(:token, value)
-
-        result = described_class.find_by_fallback_token(:token, plaintext_token_value)
-
-        expect(result).to eq(sha512_token)
-        expect(described_class).to have_received(:upgrade_fallback_value).with(sha512_token, :token,
-          plaintext_token_value)
-      end
-
       it 'upgrade legacy plain text tokens' do
         described_class.find_by_fallback_token(:token, plain_token.plaintext_token)
-        pbkdf2_hash = Gitlab::DoorkeeperSecretStoring::Token::Pbkdf2Sha512.transform_secret(plain_token.plaintext_token)
-        expect(plain_token.reload.token).to eq(pbkdf2_hash)
+        sha512_hash = Gitlab::DoorkeeperSecretStoring::Sha512Hash.transform_secret(plain_token.plaintext_token)
+        expect(plain_token.reload.token).to eq(sha512_hash)
       end
 
       it 'returns nil when no strategy finds a match' do
@@ -131,12 +130,6 @@ RSpec.describe OauthAccessToken, feature_category: :system_access do
     end
   end
 
-  describe '.matching_token_for' do
-    it 'does not find existing tokens' do
-      expect(described_class.matching_token_for(app_one, token.resource_owner, token.scopes)).to be_nil
-    end
-  end
-
   describe '#expires_in' do
     context 'when token has expires_in value set' do
       it 'uses the expires_in value' do
