@@ -147,76 +147,46 @@ RSpec.describe Organizations::OrganizationUser, type: :model, feature_category:
 
   it_behaves_like 'having unique enum values'
 
-  describe '.update_default_organization_record_for' do
-    let_it_be(:default_organization) { create(:organization, :default) }
-    let_it_be(:user) { create(:user, organizations: []) }
+  describe '.update_home_organization_record_for' do
+    let_it_be(:organization) { create(:organization) }
+    let_it_be(:user) { create(:user, organization: organization, organizations: []) }
     let_it_be(:user_id) { user.id }
     let(:user_is_admin) { false }
 
-    subject(:update_default_organization_record) do
-      described_class.update_default_organization_record_for(user_id, user_is_admin: user_is_admin)
+    subject(:update_home_organization_record) do
+      described_class.update_home_organization_record_for(user, user_is_admin: user_is_admin)
     end
 
     context 'when record does not exist yet' do
       it 'creates record with correct attributes' do
-        expect { update_default_organization_record }.to change { described_class.count }.by(1)
-        expect(default_organization.user?(user)).to be(true)
+        expect { update_home_organization_record }.to change { described_class.count }.by(1)
+        expect(organization.user?(user)).to be(true)
       end
     end
 
     context 'when entry already exists' do
-      let_it_be(:organization_user) { create(:organization_user, user: user, organization: default_organization) }
+      let_it_be(:organization_user) { create(:organization_user, user: user, organization: organization) }
 
       it 'does not create or update existing record' do
-        expect { update_default_organization_record }.not_to change { described_class.count }
+        expect { update_home_organization_record }.not_to change { described_class.count }
       end
 
       context 'when access_level changes' do
         let(:user_is_admin) { true }
 
         it 'changes access_level on the existing record' do
-          expect(default_organization.owner?(user)).to be(false)
+          expect(organization.owner?(user)).to be(false)
 
-          expect { update_default_organization_record }.not_to change { described_class.count }
+          expect { update_home_organization_record }.not_to change { described_class.count }
 
-          expect(default_organization.owner?(user)).to be(true)
+          expect(organization.owner?(user)).to be(true)
         end
       end
     end
-
-    context 'when creating with invalid user_id' do
-      let(:user_id) { nil }
-
-      it 'does not add a new record' do
-        expect { update_default_organization_record }.not_to change { described_class.count }
-      end
-    end
-
-    context 'when organization is not found' do
-      before do
-        stub_const("Organizations::Organization::DEFAULT_ORGANIZATION_ID", non_existing_record_id)
-      end
-
-      it 'does not raise validation error' do
-        expect { update_default_organization_record }.not_to raise_error
-      end
-    end
-
-    context 'when another error occurs' do
-      before do
-        allow_next_instance_of(described_class) do |instance|
-          allow(instance).to receive(:save!).and_raise(ActiveRecord::RecordInvalid.new(instance))
-        end
-      end
-
-      it 'raise error' do
-        expect { update_default_organization_record }.to raise_error(ActiveRecord::RecordInvalid)
-      end
-    end
   end
 
-  describe '.default_organization_access_level' do
-    subject { described_class.default_organization_access_level(user_is_admin: user_is_admin) }
+  describe '.home_organization_access_level' do
+    subject { described_class.home_organization_access_level(user_is_admin: user_is_admin) }
 
     context 'when user is admin' do
       let(:user_is_admin) { true }
