@@ -6,7 +6,6 @@ RSpec.describe 'Export work items', feature_category: :team_planning do
   include GraphqlHelpers
 
   let_it_be(:project) { create(:project) }
-  let_it_be(:reporter) { create(:user, reporter_of: project) }
   let_it_be(:guest) { create(:user, guest_of: project) }
   let_it_be(:work_item) { create(:work_item, project: project) }
 
@@ -14,14 +13,8 @@ RSpec.describe 'Export work items', feature_category: :team_planning do
   let(:mutation) { graphql_mutation(:workItemsCsvExport, input) }
   let(:mutation_response) { graphql_mutation_response(:work_items_csv_export) }
 
-  context 'when user is not allowed to export work items' do
-    let(:current_user) { guest }
-
-    it_behaves_like 'a mutation that returns a top-level access error'
-  end
-
   context 'when user has permissions to export work items' do
-    let(:current_user) { reporter }
+    let(:current_user) { guest }
     let(:input) do
       super().merge(
         'selectedFields' => %w[TITLE DESCRIPTION AUTHOR TYPE AUTHOR_USERNAME CREATED_AT],
@@ -52,7 +45,7 @@ RSpec.describe 'Export work items', feature_category: :team_planning do
 
       expect(mutation_response['message']).to eq(
         'Your CSV export request has succeeded. The result will be emailed to ' \
-        "#{reporter.notification_email_or_default}."
+        "#{guest.notification_email_or_default}."
       )
       expect(mutation_response['errors']).to be_empty
     end
