@@ -446,14 +446,17 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
     end
 
     context "POST #{source_type}s/:id/access_tokens" do
-      let(:params) do
-        { name: "test", description: "description", scopes: ["api"], expires_at: expires_at,
-          access_level: access_level }
+      let(:base_params) do
+        { name: "test", description: "description", scopes: ["api"] }
       end
 
       let(:expires_at) { 1.month.from_now }
       let(:access_level) { 20 }
 
+      let(:params) do
+        base_params.merge(expires_at: expires_at, access_level: access_level)
+      end
+
       subject(:create_token) { post api("/#{source_type}s/#{resource_id}/access_tokens", user), params: params }
 
       context "when the user has valid permissions" do
@@ -461,7 +464,7 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
 
         context "with valid params" do
           context "with full params" do
-            it "creates a #{source_type} access token with the params", :aggregate_failures do
+            it "creates a #{source_type} access token with the user-provided params", :aggregate_failures do
               create_token
 
               expect(response).to have_gitlab_http_status(:created)
@@ -474,26 +477,59 @@ RSpec.describe API::ResourceAccessTokens, feature_category: :system_access do
             end
           end
 
-          context "when 'expires_at' is not set" do
-            let(:expires_at) { nil }
+          context "when 'expires_at' is not provided" do
+            let(:params) { base_params.merge(access_level: access_level) }
 
-            it "creates a #{source_type} access token with the default expires_at value", :aggregate_failures do
-              create_token
-              # When the test run just before 00:00Z sometimes this expires_at is one day later.
-              # We have tried both freeze_time and time_travel_to, but it doesn't work. It seems `create_token`
-              # operates in a different context.
-              expires_at = PersonalAccessToken::MAX_PERSONAL_ACCESS_TOKEN_LIFETIME_IN_DAYS.days.from_now.to_date
+            context 'when feature flag :allow_resource_access_token_creation_without_expiry_date is disabled' do
+              before do
+                stub_feature_flags(allow_resource_access_token_creation_without_expiry_date: false)
+              end
 
-              expect(response).to have_gitlab_http_status(:created)
-              expect(json_response["name"]).to eq("test")
-              expect(json_response["scopes"]).to eq(["api"])
-              # Because of the above issue, we decided to compare with `<=` operator instead of `eq`
-              expect(json_response["expires_at"].to_date).to be <= expires_at
+              it 'returns a 400 bad request' do
+                create_token
+
+                expect(response).to have_gitlab_http_status(:bad_request)
+                expect(json_response['message']).to eq('400 Bad request - expires_at is missing')
+              end
+            end
+
+            context 'when feature flag :allow_resource_access_token_creation_without_expiry_date is enabled' do
+              before do
+                # Note: 'resource' is available from the outer 'it_behaves_like' context
+                stub_feature_flags(allow_resource_access_token_creation_without_expiry_date: resource)
+              end
+
+              context "when 'require_personal_access_token_expiry' is enabled" do
+                before do
+                  stub_application_setting(require_personal_access_token_expiry: true)
+                end
+
+                it 'returns a 400 bad request' do
+                  create_token
+
+                  expect(response).to have_gitlab_http_status(:bad_request)
+                  expect(json_response['message']).to eq('400 Bad request - expires_at is missing')
+                end
+              end
+
+              context "when 'require_personal_access_token_expiry' is disabled" do
+                before do
+                  stub_application_setting(require_personal_access_token_expiry: false)
+                end
+
+                it "creates a token with no expiry date (null)", :aggregate_failures do
+                  create_token
+
+                  expect(response).to have_gitlab_http_status(:created)
+                  expect(json_response["expires_at"]).to be_nil
+                  expect(json_response["name"]).to eq("test")
+                end
+              end
             end
           end
 
           context "when 'access_level' is not set" do
-            let(:access_level) { nil }
+            let(:params) { base_params.merge(expires_at: expires_at) }
 
             it "creates a #{source_type} access token with the default access level", :aggregate_failures do
               create_token
