@@ -7,6 +7,13 @@ RSpec.describe API::Settings, 'Settings', :do_not_mock_admin_mode_setting, featu
 
   let_it_be(:admin) { create(:admin) }
 
+  let_it_be(:default_organization) { create(:organization) }
+
+  before do
+    stub_env('IN_MEMORY_APPLICATION_SETTINGS', 'false')
+    allow(::Organizations::Organization).to receive(:default_organization).and_return(default_organization)
+  end
+
   describe "GET /application/settings" do
     before do
       # Testing config file config/gitlab.yml becomes SSOT for this API
@@ -70,6 +77,7 @@ RSpec.describe API::Settings, 'Settings', :do_not_mock_admin_mode_setting, featu
       expect(json_response['max_decompressed_archive_size']).to eq(25600)
       expect(json_response['max_terraform_state_size_bytes']).to eq(0)
       expect(json_response['pipeline_limit_per_project_user_sha']).to eq(0)
+      expect(json_response['pipeline_limit_per_user']).to eq(0)
       expect(json_response['delete_inactive_projects']).to be(false)
       expect(json_response['inactive_resource_access_tokens_delete_after_days']).to eq(30)
       expect(json_response['inactive_projects_delete_after_months']).to eq(2)
@@ -105,12 +113,56 @@ RSpec.describe API::Settings, 'Settings', :do_not_mock_admin_mode_setting, featu
       expect(json_response['require_personal_access_token_expiry']).to eq(true)
       expect(json_response['organization_cluster_agent_authorization_enabled']).to eq(false)
       expect(json_response['terraform_state_encryption_enabled']).to eq(true)
+      expect(json_response['iframe_rendering_enabled']).to be(false)
+      expect(json_response['iframe_rendering_allowlist']).to eq([])
+      expect(json_response['authn_data_retention_cleanup_enabled']).to eq(false)
     end
   end
 
   describe "PUT /application/settings" do
     let(:group) { create(:group) }
 
+    context 'iframe in markdown settings' do
+      it 'updates iframe_rendering_enabled and iframe_rendering_allowlist via array' do
+        put api('/application/settings', admin),
+          params: {
+            iframe_rendering_enabled: true,
+            iframe_rendering_allowlist: ['example.com', 'videos.example.com:443', 'https://example.net/']
+          }
+
+        expect(response).to have_gitlab_http_status(:ok)
+        expect(json_response['iframe_rendering_enabled']).to be(true)
+        expect(json_response['iframe_rendering_allowlist']).to match_array(['example.com', 'videos.example.com:443', 'example.net'])
+        expect(ApplicationSetting.current.iframe_rendering_enabled?).to be(true)
+        expect(ApplicationSetting.current.iframe_rendering_allowlist).to match_array(['example.com', 'videos.example.com:443', 'example.net'])
+      end
+
+      it 'denies bad allowlist entries' do
+        put api('/application/settings', admin),
+          params: {
+            iframe_rendering_enabled: true,
+            iframe_rendering_allowlist: ['gopher://gopherz.tv']
+          }
+
+        expect(response).to have_gitlab_http_status(:bad_request)
+        expect(json_response['message']['iframe_rendering_allowlist']).to include("'gopher://gopherz.tv' is not a valid domain name")
+        expect(ApplicationSetting.current.iframe_rendering_allowlist.join(',')).not_to include('gopherz')
+      end
+
+      it 'allows a raw string for iframe_rendering_allowlist_raw' do
+        raw = "example.com\nvideos.example.com:443"
+        put api('/application/settings', admin),
+          params: {
+            iframe_rendering_allowlist_raw: raw
+          }
+
+        expect(response).to have_gitlab_http_status(:ok)
+        expect(json_response['iframe_rendering_allowlist']).to match_array(['example.com', 'videos.example.com:443'])
+        expect(json_response['iframe_rendering_allowlist_raw']).to eq(raw)
+        expect(ApplicationSetting.current.iframe_rendering_allowlist).to match_array(['example.com', 'videos.example.com:443'])
+      end
+    end
+
     context "custom repository storage type set in the config" do
       before do
         # Add a possible storage to the config
@@ -239,7 +291,8 @@ RSpec.describe API::Settings, 'Settings', :do_not_mock_admin_mode_setting, featu
               enabled: false,
               preset: 'open_vsx'
             },
-            terraform_state_encryption_enabled: false
+            terraform_state_encryption_enabled: false,
+            authn_data_retention_cleanup_enabled: true
           }
 
         expect(response).to have_gitlab_http_status(:ok)
@@ -335,6 +388,7 @@ RSpec.describe API::Settings, 'Settings', :do_not_mock_admin_mode_setting, featu
         expect(json_response['require_personal_access_token_expiry']).to be(false)
         expect(json_response['vscode_extension_marketplace']).to eq({ "enabled" => false, "preset" => 'open_vsx' })
         expect(json_response['terraform_state_encryption_enabled']).to eq(false)
+        expect(json_response['authn_data_retention_cleanup_enabled']).to eq(true)
       end
     end
 
@@ -1042,6 +1096,40 @@ RSpec.describe API::Settings, 'Settings', :do_not_mock_admin_mode_setting, featu
       end
     end
 
+    context 'with pipeline_limit_per_user' do
+      it 'updates the settings' do
+        put api("/application/settings", admin), params: {
+          pipeline_limit_per_user: 30
+        }
+
+        expect(response).to have_gitlab_http_status(:ok)
+        expect(json_response).to include(
+          'pipeline_limit_per_user' => 30
+        )
+      end
+
+      it 'updates the settings with zero value' do
+        put api("/application/settings", admin), params: {
+          pipeline_limit_per_user: 0
+        }
+
+        expect(response).to have_gitlab_http_status(:ok)
+        expect(json_response).to include(
+          'pipeline_limit_per_user' => 0
+        )
+      end
+
+      it 'does not allow null values' do
+        put api("/application/settings", admin), params: {
+          pipeline_limit_per_user: nil
+        }
+
+        expect(response).to have_gitlab_http_status(:bad_request)
+        expect(json_response['message']['pipeline_limit_per_user'])
+          .to include(a_string_matching('is not a number'))
+      end
+    end
+
     context 'with ci_max_includes' do
       it 'updates the settings' do
         put api("/application/settings", admin), params: {
