@@ -36,10 +36,10 @@ RSpec.describe Groups::TransferService, :sidekiq_inline, feature_category: :grou
 
   context 'handling packages' do
     let_it_be(:group) { create(:group) }
-    let_it_be(:new_group) { create(:group) }
-
     let_it_be(:project) { create(:project, namespace: group) }
 
+    let!(:new_group) { create(:group) }
+
     before do
       group.add_owner(user)
       new_group&.add_owner(user)
@@ -59,6 +59,14 @@ RSpec.describe Groups::TransferService, :sidekiq_inline, feature_category: :grou
 
       it_behaves_like 'transfer allowed'
 
+      context 'with packages_projects_finder is disabled' do
+        before do
+          stub_feature_flags(packages_projects_finder: false)
+        end
+
+        it_behaves_like 'transfer allowed'
+      end
+
       context 'with a project within subgroup' do
         let_it_be(:root_group) { create(:group) }
         let_it_be_with_reload(:group) { create(:group, parent: root_group) }
