@@ -147,6 +147,7 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'BulkImports::PipelineBatchWorker' => 6,
         'BulkImports::FinishProjectImportWorker' => 3,
         'BulkImports::TransformReferencesWorker' => 3,
+        'Cells::LostTransactionRecoveryWorker' => 3,
         'Chaos::CpuSpinWorker' => 3,
         'Chaos::DbSleepWorker' => false,
         'Chaos::DbSpinWorker' => 3,
@@ -168,6 +169,7 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Ci::MergeRequests::AddTodoWhenBuildFailsWorker' => 3,
         'Ci::Minutes::UpdateProjectAndNamespaceUsageWorker' => 3,
         'Ci::Minutes::UpdateGitlabHostedRunnerMonthlyUsageWorker' => 3,
+        'Ci::Observability::ExportWorker' => 3,
         'Ci::PipelineArtifacts::CoverageReportWorker' => 3,
         'Ci::PipelineArtifacts::CreateQualityReportWorker' => 3,
         'Ci::PipelineCleanupRefWorker' => 3,
@@ -208,6 +210,13 @@ RSpec.describe 'Every Sidekiq worker', feature_category: :shared do
         'Database::BatchedBackgroundMigration::CiExecutionWorker' => 0,
         'Database::BatchedBackgroundMigration::MainExecutionWorker' => 0,
         'Database::BatchedBackgroundMigration::SecExecutionWorker' => 0,
+        'Database::BackgroundOperation::BaseOrchestratorWorker' => 0,
+        'Database::BackgroundOperation::MainOrchestratorWorker' => 0,
+        'Database::BackgroundOperation::CiOrchestratorWorker' => 0,
+        'Database::BackgroundOperation::SecOrchestratorWorker' => 0,
+        'Database::BackgroundOperation::MainOrchestratorCellLocalWorker' => 0,
+        'Database::BackgroundOperation::CiOrchestratorCellLocalWorker' => 0,
+        'Database::BackgroundOperation::SecOrchestratorCellLocalWorker' => 0,
         'Database::CollationCheckerWorker' => false,
         'Database::SchemaCheckerWorker' => false,
         'DeleteDiffFilesWorker' => 3,
